@@ -1,4 +1,4 @@
-/*$Id: mg_.h,v 21.14 2002/03/26 09:20:13 al Exp $ -*- C++ -*-
+/*$Id: mg_.h,v 24.12 2003/12/14 01:58:28 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -86,30 +86,63 @@ protected:
   std::list<T*> _list;
   virtual void parse(CS& f) = 0;
   virtual ~List_Base() {
-    for (std::list<T*>::iterator i = _list.begin(); i != _list.end(); ++i) {
+    for (typename std::list<T*>::iterator
+	   i = _list.begin(); i != _list.end(); ++i) {
       delete *i;
     }
   }
 public:
-  typedef std::list<T*>::const_iterator const_iterator;
+  typedef typename std::list<T*>::const_iterator const_iterator;
   const_iterator begin()const	 {return _list.begin();}
   const_iterator end()const	 {return _list.end();}
   bool		 is_empty()const {return _list.empty();}
   int		 size()const	 {return _list.size();}
 };
 /*--------------------------------------------------------------------------*/
-template <class T, char, char>
+template <class T, char BEGIN, char END>
 class List
   :public List_Base<T>
 {
-  void parse(CS& f);
+  void parse(CS& file) {
+    C_Comment   dummy_c_comment;
+    Cxx_Comment dummy_cxx_comment;
+    int paren = file.skip1b(BEGIN);
+    int here = file.cursor();
+    {for (;;) {
+      get(file, "/*$$", &dummy_c_comment);
+      get(file, "//$$", &dummy_cxx_comment);
+      if (file.stuck(&here)) {
+	paren -= file.skip1b(END);
+	if (paren == 0) {
+	  break;
+	}
+	T* p = new T(file);
+	{if (!file.stuck(&here)) {
+	  _list.push_back(p);
+	}else {
+	  delete p;
+	  file.warn(0, "not valid here");
+	  break;
+	}}
+      }
+    }}
+  }
 };
 /*--------------------------------------------------------------------------*/
 template <class T>
 class Collection
   :public List_Base<T>
 {
-  void parse(CS& f);
+  void parse(CS& file) {
+    int here = file.cursor();
+    T* m = new T(file);
+    {if (!file.stuck(&here)) {
+      _list.push_back(m);
+    }else{
+      delete m;
+      file.warn(0, "what's this??");
+    }}
+  }
 };
 /*--------------------------------------------------------------------------*/
 class C_Comment
@@ -311,6 +344,7 @@ public:
   const std::string& omit()const 	{return _omit;}
   const std::string& reverse()const 	{return _reverse;}
   const std::string& state()const	{return _state;}
+	int	     num_nodes()const	{return ports().size();}
 };
 typedef Collection<Element> Element_List;
 /*--------------------------------------------------------------------------*/
@@ -346,7 +380,8 @@ class Circuit
   :public Base
 {
   bool		_sync;
-  Port_List	_port_list;
+  Port_List	_required_nodes;
+  Port_List	_optional_nodes;
   Port_List	_local_nodes;
   Element_List	_element_list;
   Args_List	_args_list;
@@ -354,11 +389,14 @@ class Circuit
 public:
   Circuit() : _sync(false) {}
   bool		      sync()const	 {return _sync;}
-  const Port_List&    ports()const	 {return _port_list;}
+  const Port_List&    req_nodes()const	 {return _required_nodes;}
+  const Port_List&    opt_nodes()const	 {return _optional_nodes;}
   const Port_List&    local_nodes()const {return _local_nodes;}
   const Element_List& elements()const	 {return _element_list;}
   const Args_List&    args_list()const	 {return _args_list;}
-	int	      num_nodes()const	 {return ports().size();}
+	int	      min_nodes()const	 {return req_nodes().size();}
+        int	      max_nodes()const {return opt_nodes().size()+min_nodes();}
+	int	      net_nodes()const	 {return max_nodes();}
 };
 /*--------------------------------------------------------------------------*/
 class Probe
@@ -433,7 +471,9 @@ public:
   const Code_Block&	 tr_eval()const		{return _tr_eval;}
   const Eval_List&	 eval_list()const	{return _eval_list;}
   const Function_List&	 function_list()const	{return _function_list;}
-  	int		 num_nodes()const	{return circuit().num_nodes();}
+    	int		 min_nodes()const	{return circuit().min_nodes();}
+    	int		 max_nodes()const	{return circuit().max_nodes();}
+    	int		 net_nodes()const	{return circuit().net_nodes();}
 };
 typedef Collection<Device> Device_List;
 /*--------------------------------------------------------------------------*/
