@@ -1,4 +1,4 @@
-/*$Id: mg_out_common.cc,v 21.14 2002/03/26 09:20:13 al Exp $ -*- C++ -*-
+/*$Id: mg_out_common.cc,v 24.5 2003/04/27 01:04:58 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -129,9 +129,11 @@ static void make_common_parse(std::ofstream& out, const Device& d)
       "  }\n";
   }
   out << "  int here = cmd.cursor();\n"
-    "  do{\n";
+    "  do{\n"
+    "    0\n";
   make_get_param_list(out, d.common().raw());
-  out << "  }while (cmd.more() && !cmd.stuck(&here));\n"
+  out << "    ;\n"
+    "  }while (cmd.more() && !cmd.stuck(&here));\n"
     "  cmd.check(bWARNING, \"what's this?\");\n"
     "}\n"
     "/*--------------------------------------"
@@ -156,10 +158,10 @@ static void make_common_expand(std::ofstream& out, const Device& d)
 {
   out << "void COMMON_" << d.name() << "::expand(const COMPONENT* d)\n"
     "{\n"
+    "  const COMMON_" << d.name() << "* c = this;\n"
     "  const MODEL_" << d.model_type() << "* m = dynamic_cast<const MODEL_" 
       << d.model_type() << "*>(attach_model(d));\n"
     "  if (!m) {\n"
-    "    unreachable();\n"
     "    error(bERROR, d->long_label() + \": model \" + modelname()\n"
     "          + \" is not a " << d.parse_name() << "\\n\");\n"
     "  }\n"
