@@ -1,4 +1,4 @@
-/*$Id: c__cmd.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: c__cmd.cc,v 22.16 2002/08/04 22:42:30 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -42,8 +42,8 @@ void CMD::cmdproc(const std::string& cs)
   
   timecheck.stop().reset().start();
 
-  cmd.ematch("*>");
-  while (cmd.ematch("-->")) {
+  cmd.ematch(ANTI_COMMENT);
+  while (cmd.ematch(I_PROMPT)) {
     /* skip any number of these */
   }
 
@@ -70,7 +70,6 @@ void CMD::cmdproc(const std::string& cs)
   else if (cmd.pmatch("GET"))	   get(cmd);
   else if (cmd.pmatch("IC"))	   ic(cmd);
   else if (cmd.pmatch("INClude"))  include(cmd);
-  else if (cmd.pmatch("INSert"))   insert(cmd);
   else if (cmd.pmatch("List"))	   do_list(cmd);
   else if (cmd.pmatch("LOg"))	   logger(cmd);
   else if (cmd.pmatch("MACro"))	   subckt(cmd);
@@ -96,7 +95,7 @@ void CMD::cmdproc(const std::string& cs)
   else if (cmd.pmatch("STatus"))   status(cmd);
   else if (cmd.pmatch("SUbckt"))   subckt(cmd);
   else if (cmd.pmatch("SWeep"))    sweep(cmd);
-  else if (cmd.pmatch("TEmp"))	   temp(cmd);
+  else if (cmd.pmatch("TEmperature")) temp(cmd);
   else if (cmd.pmatch("TF"))	   tf(cmd);
   else if (cmd.pmatch("TItle"))    title(cmd);
   else if (cmd.pmatch("TRansient"))tr(cmd);
