@@ -1,4 +1,4 @@
-/*$Id: c_crtset.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: c_crtset.cc,v 22.19 2002/09/26 04:54:38 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -128,16 +128,8 @@ struct graph *initcrt()
   switch (crttype){
   case 'b':
     return initbasic(&d);
-#ifdef MSDOS
-  case 'i':
-    return initibm(&d);
-#endif
   case 'p':
     return initpostscript(&d);
-#ifdef SUNVIEW
-  case 's':
-    return initsun(&d);
-#endif
   case 'u':
     return initunix(&d);
   case 'x':
