@@ -1,4 +1,4 @@
-/*$Id: c_fanout.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: c_fanout.cc,v 24.2 2003/02/23 09:18:00 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -26,7 +26,7 @@
 #include "c_comand.h"
 /*--------------------------------------------------------------------------*/
 //	void	CMD::fanout(CS&);
-static	void	checklist(const CARD_LIST&,int,OMSTREAM);
+static	void	checklist(const CARD_LIST&, const node_t&, OMSTREAM);
 /*--------------------------------------------------------------------------*/
 void CMD::fanout(CS& cmd)
 {
@@ -66,7 +66,8 @@ void CMD::fanout(CS& cmd)
       break;
     }}
   }
-  
+  SIM::init();
+
   if (start < 0){
     start = 0;
   }
@@ -81,7 +82,7 @@ void CMD::fanout(CS& cmd)
   out << "Node:  Branches\n";
   for (int ii = start;  ii <= stop;  ++ii){
     out.form("%4u:",ii);
-    checklist(CARD_LIST::card_list, ii, out);
+    checklist(CARD_LIST::card_list, node_t(ii), out);
     out << '\n';
   }
 }
@@ -89,7 +90,7 @@ void CMD::fanout(CS& cmd)
 /* checklist: print a list of all elements connecting to a node
  *	recursive, for subckts
  */
-static void checklist(const CARD_LIST& cl, int node, OMSTREAM out)
+static void checklist(const CARD_LIST& cl, const node_t& node, OMSTREAM out)
 {
   for (CARD_LIST::const_iterator ci = cl.begin(); ci != cl.end(); ++ci){
     if ((**ci).is_device()){
