@@ -1,4 +1,4 @@
-/*$Id: c_getckt.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: c_getckt.cc,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -85,7 +85,7 @@ void CMD::build(CS& cmd)
   CARD* brh;
   do{
     char buffer[BIGBUFLEN];
-    getcmd(">",buffer,BIGBUFLEN);
+    getcmd(CKT_PROMPT, buffer, BIGBUFLEN);
     CS cs(buffer);
     brh = parsebranch(cs, true);
   }while (exists(brh));
@@ -161,16 +161,17 @@ static void getmerge(CS& cmd)
   bool  quiet = false;		/* don't echo title */
   int here = cmd.cursor();
   do{
-    get(cmd, "Echo",  &echoon);
-    get(cmd, "List",  &liston);
-    get(cmd, "Quiet", &quiet);
+    0
+      || get(cmd, "Echo",  &echoon)
+      || get(cmd, "List",  &liston)
+      || get(cmd, "Quiet", &quiet)
+      ;
   }while (cmd.more() && !cmd.stuck(&here));
   cmd.check(bWARNING, "need echo, list, or quiet");
   
   {
     std::string buffer(getlines(filen)); // title
     if (buffer.empty()) {
-      untested();
       error(bWARNING, "empty circuit file\n");
     }
     head = buffer;
@@ -241,8 +242,8 @@ static CARD *cparse(CS& cmd)
 {
   cmd.skipbl();
   cmd.is_digit() && cmd.ctoi();	/* ignore line numbers */
-  cmd.ematch("*>"); /* mark so spice ignores but gnucap reads */
-  while (cmd.skip1(">")) {
+  cmd.ematch(ANTI_COMMENT); /* mark so spice ignores but gnucap reads */
+  while (cmd.ematch(CKT_PROMPT)) {
     /* skip any number of these */
   }
   
