@@ -1,4 +1,4 @@
-/*$Id: d_admit.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_admit.cc,v 23.1 2002/11/06 07:47:50 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -29,6 +29,7 @@
  *		m.x  = volts(control), m.c0 = 0,    acg = m.c1 = mhos
  *		_loss0 == 1/R. (mhos)
  */
+#include "l_stlextra.h"
 #include "d_admit.h"
 /*--------------------------------------------------------------------------*/
 void DEV_ADMITTANCE::precalc()
@@ -47,7 +48,7 @@ void DEV_ADMITTANCE::precalc()
 /*--------------------------------------------------------------------------*/
 bool DEV_ADMITTANCE::do_tr()
 {
-  {if (has_tr_eval()) {
+  {if (using_tr_eval()) {
     _m0.x = tr_involts_limited();
     _y0.x = _m0.x;
     _y0.f0 = _m0.c1 * _m0.x + _m0.c0;	/* BUG:  patch for diode */
@@ -144,6 +145,16 @@ DEV_CPOLY_G::DEV_CPOLY_G()
 {
 }
 /*--------------------------------------------------------------------------*/
+DEV_CPOLY_G::~DEV_CPOLY_G()
+{
+  delete [] _old_values;
+  {if (net_nodes() > NODES_PER_BRANCH) {
+    delete [] _n;
+  }else{
+    // it is part of a base class
+  }}
+}
+/*--------------------------------------------------------------------------*/
 bool DEV_CPOLY_G::do_tr_con_chk_and_q()
 {
   q_load();
@@ -232,22 +243,43 @@ void DEV_CPOLY_G::ac_load()
 void DEV_CPOLY_G::set_parameters(const std::string& Label, CARD *Owner,
 				 COMMON_COMPONENT *Common, double Value,
 				 int n_states, double states[],
-				 int n_nodes, const node_t nodes[],
-				 const double* inputs[])
+				 int n_nodes, const node_t nodes[])
+  //				 const double* inputs[])
 {
-  COMPONENT::set_parameters(Label, Owner, Common, Value, 0, 0, n_nodes, nodes);
+  bool first_time = (net_nodes() == 0);
+
+  set_Label(Label);
+  set_owner(Owner);
+  set_value(Value);
+  attach_common(Common);
+
+  {if (first_time) {
+    _n_ports = n_nodes/2; // sets num_nodes() = _n_ports*2
+    assert(_n_ports == n_states-1);
+
+    assert(!_old_values);
+    _old_values = new double[n_states];
+
+    {if (net_nodes() > NODES_PER_BRANCH) {
+      // allocate a bigger node list
+      _n = new node_t[net_nodes()];
+    }else{
+      // use the default node list, already set
+    }}      
+  }else{
+    assert(_n_ports == n_states-1);
+    assert(_old_values);
+    assert(net_nodes() == n_nodes);
+    // assert could fail if changing the number of nodes after a run
+  }}
+
+  //_inputs = inputs;
+  _inputs = 0;
   _values = states;
-  _n_ports = n_nodes/2;
-  assert(_n_ports == n_states-1);
-
   std::fill_n(_values, n_states, 0.);
-  _old_values = new double[n_states];
   std::fill_n(_old_values, n_states, 0.);
-
-  set_port_count(n_nodes);
-  _n = new node_t[num_nodes()];
-  std::copy_n(nodes, num_nodes(), _n);
-  _inputs = inputs;
+  notstd::copy_n(nodes, net_nodes(), _n);
+  assert(net_nodes() == _n_ports * 2);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
