@@ -1,4 +1,4 @@
-/*$Id: d_cap.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_cap.cc,v 23.1 2002/11/06 07:47:50 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -25,17 +25,17 @@
  * i.x = volts, i.f0 = amps,	      i.f1 = mhos
  * m.x = volts, m.c0 = amps,    acg = m.c1 = mhos
  */
+#include "l_stlextra.h"
 #include "ap.h"
 #include "d_cap.h"
 /*--------------------------------------------------------------------------*/
 bool DEV_CAPACITANCE::do_tr()
 {
-  initial_condition = NOT_INPUT;
-  {if (has_tr_eval()) {
-    _m0.x = _i0.x = _y0.x = tr_involts_limited();
+  {if (using_tr_eval()) {
+    _y0.x = tr_involts_limited();
     tr_eval();
   }else{
-    _m0.x = _i0.x = _y0.x = tr_involts();
+    _y0.x = tr_involts();
     assert(_y0.f1 == value());
     _y0.f0 = _y0.x * _y0.f1;
     assert(converged());
@@ -46,18 +46,13 @@ bool DEV_CAPACITANCE::do_tr()
   _q[0] = _y0;
 
   _i0.x  = _y0.x;
-  _i0.f0 = integrate();
+  _i0.f0 = differentiate();
   _i0.f1 = tr_c_to_g(_q[0].f1, _i0.f1);
 
   _m0 = CPOLY1(_i0);
   return converged();
 }
 /*--------------------------------------------------------------------------*/
-double DEV_CAPACITANCE::tr_review()
-{
-  return review(_i0.f0, _it1.f0);
-}
-/*--------------------------------------------------------------------------*/
 void DEV_CAPACITANCE::do_ac()
 {
   {if (has_ac_eval()) {
@@ -80,8 +75,6 @@ double DEV_CAPACITANCE::tr_probe_num(CS& cmd)const
     return (_q[0].f0 - _q[1].f0) / _dt;
   }else if (cmd.pmatch("DQ")) {
     return (_q[0].f0 - _q[1].f0);
-  }else if (cmd.pmatch("TIMEFuture")) {
-    return review(_i0.f0, _it1.f0);
   }else{
     return STORAGE::tr_probe_num(cmd);
   }}
@@ -90,7 +83,6 @@ double DEV_CAPACITANCE::tr_probe_num(CS& cmd)const
 /*--------------------------------------------------------------------------*/
 bool DEV_VCCAP::do_tr()
 {
-  initial_condition = NOT_INPUT;
   _y0.x = tr_involts_limited();
   tr_eval();
 
@@ -102,7 +94,7 @@ bool DEV_VCCAP::do_tr()
   _q[0].f0 = _q[0].x * _q[0].f1; // charge
 
   _i0.x  = _q[0].x;
-  _i0.f0 = integrate();
+  _i0.f0 = differentiate();
   _i0.f1 = tr_c_to_g(_q[0].f1, _i0.f1);
 
   _m0.x  = _i0.x;
@@ -134,6 +126,19 @@ DEV_FPOLY_CAP::DEV_FPOLY_CAP()
 {
 }
 /*--------------------------------------------------------------------------*/
+DEV_FPOLY_CAP::~DEV_FPOLY_CAP() 
+{
+  delete [] _vy1;
+  delete [] _vi0;
+  delete [] _vi1;
+  {if (net_nodes() > NODES_PER_BRANCH) {
+    untested();
+    delete [] _n;
+  }else{
+    // it is part of a base class
+  }}
+}
+/*--------------------------------------------------------------------------*/
 bool DEV_FPOLY_CAP::do_tr_con_chk_and_q()
 {
   q_load();
@@ -155,7 +160,7 @@ bool DEV_FPOLY_CAP::do_tr()
   _q[0].f1 = _vy0[1];
   
   _i0.x  = _q[0].x;
-  _vi0[0] = _i0.f0 = integrate();
+  _vi0[0] = _i0.f0 = differentiate();
   _vi0[1] = _i0.f1 = tr_c_to_g(_q[0].f1, _i0.f1); 
   
   {if (_inputs) {
@@ -216,28 +221,55 @@ void DEV_FPOLY_CAP::ac_load()
 /* set: set parameters, used in model building
  */
 void DEV_FPOLY_CAP::set_parameters(const std::string& Label, CARD *Owner,
-				 COMMON_COMPONENT *Common, double Value,
-				 int n_states, double states[],
-				 int n_nodes, const node_t nodes[],
-				 const double* inputs[])
+				   COMMON_COMPONENT *Common, double Value,
+				   int n_states, double states[],
+				   int n_nodes, const node_t nodes[])
+  //				   const double* inputs[])
 {
-  COMPONENT::set_parameters(Label, Owner, Common, Value, 0, 0, n_nodes, nodes);
+  bool first_time = (net_nodes() == 0);
+
+  set_Label(Label);
+  set_owner(Owner);
+  set_value(Value);
+  attach_common(Common);
+
+  {if (first_time) {
+    _n_ports = n_nodes/2; // sets num_nodes() = _n_ports*2
+    assert(_n_ports == n_states-1);
+
+    assert(!_vy1);
+    assert(!_vi0);
+    assert(!_vi1);
+    _vy1 = new double[n_states]; 
+    _vi0 = new double[n_states];
+    _vi1 = new double[n_states];
+
+    {if (net_nodes() > NODES_PER_BRANCH) {
+      untested();
+      // allocate a bigger node list
+      _n = new node_t[net_nodes()];
+    }else{
+      // use the default node list, already set
+    }}      
+  }else{
+    //untested();
+    assert(_n_ports == n_states-1);
+    assert(_vy1);
+    assert(_vi0);
+    assert(_vi1);
+    assert(net_nodes() == n_nodes);
+    // assert could fail if changing the number of nodes after a run
+  }}
+
+  //_inputs = inputs;
+  _inputs = 0;
   _vy0 = states;
-  _n_ports = n_nodes/2;
-  assert(_n_ports == n_states-1);
-
   std::fill_n(_vy0, n_states, 0.);
-  _vy1 = new double[n_states];
   std::fill_n(_vy1, n_states, 0.);
-  _vi0 = new double[n_states];
   std::fill_n(_vi0, n_states, 0.);
-  _vi1 = new double[n_states];
   std::fill_n(_vi1, n_states, 0.);
-
-  set_port_count(n_nodes);
-  _n = new node_t[num_nodes()];
-  std::copy_n(nodes, num_nodes(), _n);
-  _inputs = inputs;
+  notstd::copy_n(nodes, net_nodes(), _n);
+  assert(net_nodes() == _n_ports * 2);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
