@@ -1,4 +1,4 @@
-/*$Id: d_cap.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_cap.h,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -36,37 +36,42 @@ protected: // override virtual
   char	   id_letter()const	{return 'C';}
   const char* dev_type()const	{return "capacitor";}
   int	   max_nodes()const	{return 2;}
-  int	   num_nodes()const	{return 2;}
   int	   min_nodes()const	{return 2;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 2;}
+  int	   net_nodes()const	{return 2;}
   bool	   is_1port()const	{return true;}
   CARD*	   clone()const		{return new DEV_CAPACITANCE(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   //void   precalc()		//STORAGE
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_passive();}
   //void   dc_begin();		//STORAGE
   //void   tr_begin();		//STORAGE
   //void   tr_restore();	//STORAGE
   //void   dc_advance();	//STORAGE
   //void   tr_advance();	//STORAGE
   //bool   tr_needs_eval();	//STORAGE
-  //void   tr_queue_eval();	//STORAGE
+  //void   tr_queue_eval();	//ELEMENT
   bool	   do_tr();
   void	   tr_load()		{tr_load_passive();}
-  double   tr_review();
+  //double tr_review();		//STORAGE
   //void   tr_accept();		//CARD/nothing
   void	   tr_unload()		{tr_unload_passive();}
-  //double tr_amps()const	//ELEMENT
   double   tr_involts()const	{return tr_outvolts();}
   double   tr_involts_limited()const {return tr_outvolts_limited();}
+  //double tr_amps()const	//ELEMENT
   double   tr_probe_num(CS&)const;
 
+  void	   ac_alloc_matrix()	{ac_alloc_matrix_passive();}
   void	   ac_begin()		{_ev = _y0.f1;}
   void	   do_ac();
   void	   ac_load()		{ac_load_passive();}
   COMPLEX  ac_involts()const	{return ac_outvolts();}
+  //COMPLEX ac_amps()const;	//ELEMENT
   //XPROBE ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
@@ -79,39 +84,44 @@ private: // override virtual
   char     id_letter()const	{return '\0';}
   const char* dev_type()const	{return "tcap";}
   int	   max_nodes()const	{return 4;}
-  int	   num_nodes()const	{untested(); return 4;}
   int	   min_nodes()const	{return 4;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 4;}
+  int	   net_nodes()const	{return 4;}
   bool	   is_1port()const	{untested(); return false;}
   bool	   is_2port()const	{return true;}
   bool	   f_is_value()const	{untested(); return true;}
   CARD*	   clone()const		{untested(); return new DEV_TRANSCAP(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   //void   precalc()		//STORAGE
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_active();}
   //void   dc_begin();		//STORAGE
   //void   tr_begin();		//STORAGE
   //void   tr_restore();	//STORAGE
   //void   dc_advance();	//STORAGE
   //void   tr_advance();	//STORAGE
   //bool   tr_needs_eval();	//STORAGE
-  //void   tr_queue_eval();	//STORAGE
+  //void   tr_queue_eval();	//ELEMENT
   //bool   do_tr();		//DEV_CAPACITANCE
   void	   tr_load()		{tr_load_active();}
-  //double tr_review();		//DEV_CAPACITANCE
+  //double tr_review();		//STORAGE
   //void   tr_accept();		//CARD/nothing
   //void   tr_unload();		//DEV_CAPACITANCE
-  //double tr_amps()const	//ELEMENT
   double   tr_involts()const	{return dn_diff(_n[IN1].v0(),_n[IN2].v0());}
   double   tr_involts_limited()const {return volts_limited(_n[IN1],_n[IN2]);}
+  //double tr_amps()const	//ELEMENT
   //double tr_probe_num(CS&)const;//DEV_CAPACITANCE
 
+  void	    ac_alloc_matrix()	{ac_alloc_matrix_active();}
   //void    ac_begin();		//DEV_CAPACITANCE
   //void    do_ac();		//DEV_CAPACITANCE
   void	    ac_load()		{untested(); ac_load_active();}
   //COMPLEX ac_involts()const;	//DEV_CAPACITANCE
+  //COMPLEX ac_amps()const;	//ELEMENT
   //XPROBE  ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
@@ -125,38 +135,43 @@ private: // override virtual
   char     id_letter()const	{return '\0';}
   const char* dev_type()const	{return "vccap";}
   int	   max_nodes()const	{return 4;}
-  int	   num_nodes()const	{untested(); return 4;}
   int	   min_nodes()const	{return 4;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 4;}
+  int	   net_nodes()const	{return 4;}
   bool	   is_2port()const	{return true;}
   bool	   f_is_value()const	{untested(); return true;}
   CARD*	   clone()const		{return new DEV_VCCAP(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   //void   precalc()		//STORAGE
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_extended();}
   //void   dc_begin();		//STORAGE
   //void   tr_begin();		//STORAGE
   //void   tr_restore();	//STORAGE
   //void   dc_advance();	//STORAGE
   //void   tr_advance();	//STORAGE
   //bool   tr_needs_eval();	//STORAGE
-  //void   tr_queue_eval();	//STORAGE
+  //void   tr_queue_eval();	//ELEMENT
   bool     do_tr();
   //void   tr_load();		//DEV_CAPACITANCE
-  //double tr_review();		//DEV_CAPACITANCE
+  //double tr_review();		//STORAGE
   //void   tr_accept();		//CARD/nothing
   //void   tr_unload();		//DEV_CAPACITANCE
-  //double tr_amps()const	//ELEMENT
   double   tr_involts()const	{return dn_diff(_n[IN1].v0(),_n[IN2].v0());}
   double   tr_involts_limited()const {return volts_limited(_n[IN1],_n[IN2]);}
+  //double tr_amps()const	//ELEMENT
   //double tr_probe_num(CS&)const;//DEV_CAPACITANCE
 
+  void	    ac_alloc_matrix()	{ac_alloc_matrix_extended();}
   //void    ac_begin();		//DEV_CAPACITANCE
   //void    do_ac();		//DEV_CAPACITANCE
   //void    ac_load();		//DEV_CAPACITANCE
   //COMPLEX ac_involts()const;	//DEV_CAPACITANCE
+  //COMPLEX ac_amps()const;	//ELEMENT
   //XPROBE  ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
@@ -174,49 +189,53 @@ private:
     :STORAGE(p) {incomplete(); unreachable();}
 public:
   explicit DEV_FPOLY_CAP();
-  ~DEV_FPOLY_CAP() 
-	{delete [] _vy1; delete [] _vi0; delete [] _vi1; delete [] _n;}
+  ~DEV_FPOLY_CAP();
 private: // override virtual
   char	   id_letter()const	{unreachable(); return '\0';}
   const char* dev_type()const	{unreachable(); return "pcapacitor";}
   int	   max_nodes()const	{unreachable(); return 0;}
-  int	   num_nodes()const	{return _n_ports*2;}
   int	   min_nodes()const	{unreachable(); return 0;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return _n_ports*2;}
+  int	   net_nodes()const	{return _n_ports*2;}
   CARD*	   clone()const	       {unreachable();return new DEV_FPOLY_CAP(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   //void   precalc();		//STORAGE
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_extended();}
   //void   dc_begin();		//STORAGE
   //void   tr_begin();		//STORAGE
   //void   tr_restore();	//STORAGE
   //void   dc_advance();	//STORAGE
   //void   tr_advance();	//STORAGE
-  //bool   tr_needs_eval();	//STORAGE
-  //void   tr_queue_eval();	//STORAGE
+  bool	   tr_needs_eval()	{return true;}
+  //void   tr_queue_eval();	//ELEMENT
   bool	   do_tr();
   void	   tr_load();
   double   tr_review()		{return NEVER;}//review(_i0.f0, _it1.f0);}
   //void   tr_accept();		//CARD/nothing
   void	   tr_unload();
-  double   tr_amps()const;
   double   tr_involts()const	{unreachable(); return NOT_VALID;}
   double   tr_involts_limited()const {unreachable(); return NOT_VALID;}
+  double   tr_amps()const;
   //double tr_probe_num(CS&)const;//ELEMENT
 
+  void	   ac_alloc_matrix()	{ac_alloc_matrix_extended();}
   //void   ac_begin();		//CARD/nothing
   void	   do_ac()		{ac_load();}
   void	   ac_load();
   COMPLEX  ac_involts()const	{unreachable(); return NOT_VALID;}
+  COMPLEX  ac_amps()const	{unreachable(); return NOT_VALID;}
   //XPROBE ac_probe_ext(CS&)const;//ELEMENT
 public:
   void set_parameters(const std::string& Label, CARD* Parent,
 		      COMMON_COMPONENT* Common, double Value,
 		      int state_count, double state[],
-		      int port_count, const node_t nodes[],
-		      const double* inputs[]=0);
+		      int node_count, const node_t nodes[]);
+  //		      const double* inputs[]=0);
 private:
   bool do_tr_con_chk_and_q();
 };
