@@ -1,4 +1,4 @@
-/*$Id: d_ccvs.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_ccvs.h,v 24.19 2004/01/11 23:02:30 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -36,6 +36,9 @@ private: // override virtual
   //int	   max_nodes()const	//CCSRC_BASE=4
   //int	   num_nodes()const	//CCSRC_BASE=4
   //int	   min_nodes()const	//CCSRC_BASE=4
+  //int	   out_nodes()const	//CCSRC_BASE=2
+  //int	   matrix_nodes()const	//CCSRC_BASE=4
+  //int	   net_nodes()const	//CCSRC_BASE=2
   CARD*	   clone()const		{untested(); return new DEV_CCVS(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //CCSRC_BASE
@@ -43,27 +46,30 @@ private: // override virtual
   //void   map_nodes();		//ELEMENT
   void	   precalc();
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_extended();}
   void	   dc_begin();
   void	   tr_begin()		{dc_begin();}
   void	   tr_restore()		{dc_begin();}
   //void   dc_advance();	//CARD/nothing
   //void   tr_advance();	//CARD/nothing
   //bool   tr_needs_eval();	//CCSRC_BASE
-  //void   tr_queue_eval();	//CCSRC_BASE
+  //void   tr_queue_eval();	//ELEMENT
   bool	   do_tr();
   void	   tr_load()		{tr_load_loss(); tr_load_active();}
   //double tr_review();		//CARD/nothing
   //void   tr_accept();		//CARD/nothing
   //void   tr_unload();		//CCSRC_BASE
-  //double tr_amps()const	//ELEMENT
   //double tr_involts()const;	//CCSRC_BASE
   //double tr_involts_limited()const;	//CCSRC_BASE
+  double   tr_amps()const	{untested(); return ELEMENT::tr_amps();}
   //double tr_probe_num(CS&)const;//ELEMENT
 
+  void	    ac_alloc_matrix()	{ac_alloc_matrix_extended();}
   void	    ac_begin()		{_loss1=_loss0=1./OPT::shortckt; _ev = _y0.f1;}
   void	    do_ac();
   void	    ac_load()		{unreachable(); incomplete(); /*fake*/}
   //COMPLEX ac_involts()const;	//CCSRC_BASE
+  COMPLEX   ac_amps()const	{untested(); return ELEMENT::ac_amps();}
   //XPROBE  ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
