@@ -1,4 +1,4 @@
-/*$Id: d_coil.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_coil.h,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -34,16 +34,19 @@ private: // override virtual
   char	   id_letter()const	{return 'L';}
   const char* dev_type()const	{return "inductor";}
   int	   max_nodes()const	{return 2;}
-  int	   num_nodes()const	{return 2;}
   int	   min_nodes()const	{return 2;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 2;}
+  int	   net_nodes()const	{return 2;}
   bool	   is_1port()const	{return true;}
   CARD*	   clone()const		{return new DEV_INDUCTANCE(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   void	   map_nodes();
   void     precalc();
 
+  void	   tr_alloc_matrix();
   void	   dc_begin();
   void	   tr_begin();
   void	   tr_restore();
@@ -56,19 +59,18 @@ private: // override virtual
   double   tr_review();
   //void   tr_accept();		//CARD/nothing
   void	   tr_unload();
-  //double tr_amps()const	//ELEMENT
   double   tr_involts()const	{return tr_outvolts();}
   double   tr_involts_limited()const {return tr_outvolts_limited();}
-  //double tr_probe_num(CS&)const;//ELEMENT
+  //double tr_amps()const	//ELEMENT
+  double   tr_probe_num(CS&)const;
 
+  void	   ac_alloc_matrix();
   void	   ac_begin();
   void	   do_ac();
   void	   ac_load();
   COMPLEX  ac_involts()const	{return ac_outvolts();}
+  //COMPLEX ac_amps()const;	//ELEMENT
   //XPROBE ac_probe_ext(CS&)const;//ELEMENT
-private:
-  void	   integrate();	/* will go away */
-  CPOLY1   _mt1;	/* matrix parameters, 1 time ago, will go away	*/
 };
 /*--------------------------------------------------------------------------*/
 class DEV_MUTUAL_L : public COMPONENT {
@@ -80,8 +82,10 @@ private: // override virtual
   char	   id_letter()const	{return 'K';}
   const char* dev_type()const	{untested(); return "mutual_inductor";}
   int	   max_nodes()const	{unreachable(); return 0;}
-  int	   num_nodes()const	{unreachable(); return 0;}
   int	   min_nodes()const	{unreachable(); return 0;}
+  //int	   out_nodes()const	//CARD 0
+  //int	   matrix_nodes()const	//CARD 0
+  //int	   net_nodes()const	//CARD 0
   bool	   is_2port()const	{untested(); return true;}
   CARD*	   clone()const		{untested(); return new DEV_MUTUAL_L(*this);}
   void	   parse(CS&);
