@@ -1,4 +1,4 @@
-/*$Id: d_cs.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_cs.h,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -34,17 +34,20 @@ private: // override virtual
   char	   id_letter()const	{return 'I';}
   const char* dev_type()const	{return "isource";}
   int	   max_nodes()const	{return 2;}
-  int	   num_nodes()const	{return 2;}
   int	   min_nodes()const	{return 2;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 2;}
+  int	   net_nodes()const	{return 2;}
   bool	   is_source()const	{return true;}
   bool	   f_is_value()const	{return true;}
   CARD*	   clone()const		{return new DEV_CS(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   void	   precalc();
 
+  void	   tr_alloc_matrix()	{/* nothing */}
   void	   dc_begin();
   void	   tr_begin()		{dc_begin();}
   void	   tr_restore()		{dc_begin();}
@@ -57,15 +60,17 @@ private: // override virtual
   //double tr_review();		//CARD/nothing
   //void   tr_accept();		//CARD/nothing
   void	   tr_unload()		{tr_unload_source();}
+  double   tr_involts()const	{return 0.;}
+  double   tr_involts_limited()const {unreachable(); return 0.;}
   //double tr_amps()const	//ELEMENT
-  double   tr_involts()const	{return 0;}
-  double   tr_involts_limited()const {unreachable(); return 0;}
   //double tr_probe_num(CS&)const;//ELEMENT
 
+  void	   ac_alloc_matrix()	{/* nothing */}
   void	   ac_begin()		{_acg = _ev = 0.;}
   void	   do_ac();
   void	   ac_load()		{ac_load_source();}
-  COMPLEX  ac_involts()const	{return 1.;}
+  COMPLEX  ac_involts()const	{return 0.;}
+  COMPLEX  ac_amps()const	{return _acg;}
   //XPROBE ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
