@@ -1,4 +1,4 @@
-/*$Id: d_logic.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_logic.cc,v 24.23 2004/02/01 21:12:55 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -35,6 +35,7 @@ static LOGIC_NONE Default_LOGIC(CC_STATIC);
 /*--------------------------------------------------------------------------*/
 DEV_LOGIC::DEV_LOGIC()
   :ELEMENT(),
+   _net_nodes(0),
    _lastchangenode(0),
    _quality(qGOOD),
    _failuremode("ok"),
@@ -48,6 +49,7 @@ DEV_LOGIC::DEV_LOGIC()
 /*--------------------------------------------------------------------------*/
 DEV_LOGIC::DEV_LOGIC(const DEV_LOGIC& p)
   :ELEMENT(p),
+   _net_nodes(p._net_nodes),
    _lastchangenode(0),
    _quality(qGOOD),
    _failuremode("ok"),
@@ -66,13 +68,13 @@ DEV_LOGIC::DEV_LOGIC(const DEV_LOGIC& p)
 void DEV_LOGIC::parse(CS& cmd)
 {
   parse_Label(cmd);
-  int incount = parse_nodes(cmd, max_nodes(), BEGIN_IN);
-  if (incount <= BEGIN_IN) {
-    untested();
-    incount = BEGIN_IN +1;
+  _net_nodes = parse_nodes(cmd, max_nodes(), BEGIN_IN);
+  if (_net_nodes <= BEGIN_IN) {
+    _net_nodes = BEGIN_IN +1;
     cmd.warn(bDANGER, "need more nodes");
   }
-  incount -= BEGIN_IN;
+  assert(net_nodes() == _net_nodes);
+  int incount = net_nodes() - BEGIN_IN;
   std::string modelname = cmd.ctos(TOKENTERM);
 
   COMMON_LOGIC* c = 0;
@@ -95,7 +97,7 @@ void DEV_LOGIC::print(OMSTREAM& where, int)const
   const COMMON_LOGIC* c = prechecked_cast<const COMMON_LOGIC*>(common());
   assert(c);
   where << short_label();
-  printnodes(where, num_nodes());
+  printnodes(where);
   where << ' ' << c->modelname() << ' ' << c->name() << '\n'; 
 }
 /*--------------------------------------------------------------------------*/
@@ -127,6 +129,12 @@ void DEV_LOGIC::precalc()
   subckt().precalc();
 }
 /*--------------------------------------------------------------------------*/
+void DEV_LOGIC::tr_alloc_matrix()
+{
+  subckt().tr_alloc_matrix();
+  tr_alloc_matrix_passive();
+}
+/*--------------------------------------------------------------------------*/
 void DEV_LOGIC::dc_begin()
 {
   {if (subckt().empty()) {
@@ -134,7 +142,7 @@ void DEV_LOGIC::dc_begin()
   }else{
     _gatemode = (OPT::mode==moMIXED) ? moANALOG : OPT::mode;
   }}
-  NODE* outnode = &(nstat[_n[OUTNODE].m]);
+  NODE* outnode = &(nstat[_n[OUTNODE].m_()]);
   outnode->set_mode(_gatemode);
   _oldgatemode = _gatemode;
   subckt().dc_begin();
@@ -143,12 +151,11 @@ void DEV_LOGIC::dc_begin()
 void DEV_LOGIC::tr_begin()
 {
   {if (subckt().empty()) {
-    untested();
     _gatemode = moDIGITAL;
   }else{
     _gatemode = (OPT::mode==moMIXED) ? moANALOG : OPT::mode;
   }}
-  NODE* outnode = &(nstat[_n[OUTNODE].m]);
+  NODE* outnode = &(nstat[_n[OUTNODE].m_()]);
   outnode->set_mode(_gatemode);
   _oldgatemode = _gatemode;
   subckt().tr_begin();
@@ -157,7 +164,6 @@ void DEV_LOGIC::tr_begin()
 void DEV_LOGIC::tr_restore()
 {
   {if (subckt().empty()) {
-    untested();
     _gatemode = moDIGITAL;
   }else{
     untested();
@@ -170,7 +176,7 @@ void DEV_LOGIC::dc_advance()
 {
   if (_gatemode != _oldgatemode) {
     tr_unload();
-    NODE* outnode = &(nstat[_n[OUTNODE].m]);
+    NODE* outnode = &(nstat[_n[OUTNODE].m_()]);
     outnode->set_mode(_gatemode);
     _oldgatemode = _gatemode;
   }
@@ -187,7 +193,7 @@ void DEV_LOGIC::dc_advance()
  */
 void DEV_LOGIC::tr_advance()
 {
-  NODE* outnode = &(nstat[_n[OUTNODE].m]);
+  NODE* outnode = &(nstat[_n[OUTNODE].m_()]);
   if (_gatemode != _oldgatemode) {
     tr_unload();
     outnode->set_mode(_gatemode);
@@ -239,7 +245,7 @@ void DEV_LOGIC::tr_queue_eval()
 bool DEV_LOGIC::tr_eval_digital()
 {
   assert(_gatemode == moDIGITAL);
-  NODE* outnode = &(nstat[_n[OUTNODE].m]);
+  NODE* outnode = &(nstat[_n[OUTNODE].m_()]);
   
   switch (SIM::phase) {
   case SIM::pDC_SWEEP:	untested(); tr_accept();break;
@@ -258,10 +264,11 @@ bool DEV_LOGIC::tr_eval_digital()
   _m0.x = 0.;
   _m0.c1 = 1./m->rs;
   _m0.c0 = _y0.f1 / -m->rs;
+  set_converged(conv_check());
   store_values();
   q_load();
   
-  return !outnode->is_unknown();
+  return converged();
 }
 /*--------------------------------------------------------------------------*/
 bool DEV_LOGIC::do_tr()
@@ -324,7 +331,7 @@ void DEV_LOGIC::tr_accept()
     trace0(long_label().c_str());
     trace2(ns[OUTNODE]->failure_mode(), OUTNODE, ns[OUTNODE]->quality());
     
-    for (int ii = BEGIN_IN;  ii < num_nodes();  ++ii) {
+    for (int ii = BEGIN_IN;  ii < net_nodes();  ++ii) {
       _n[ii]->to_logic(m);
       ns[ii] = &*(_n[ii]);
       if (ns[ii]->quality() < _quality) {
@@ -363,31 +370,40 @@ void DEV_LOGIC::tr_accept()
       _gatemode = moDIGITAL;
     }
     assert(_gatemode == moDIGITAL);
-    bool bypass = (SIM::bypass_ok
-		   && _lastchangenode == OUTNODE
-		   && SIM::phase == SIM::pTRAN);
-    if (!bypass) {
-      LOGICVAL newstate = c->logic_eval(&ns[BEGIN_IN]);
-      //		     ^^^^^^^^^^
-      {if (ns[OUTNODE]->is_unknown()) {
-	assert(SIM::phase == SIM::pINIT_DC  ||  SIM::phase == SIM::pDC_SWEEP);
-	ns[OUTNODE]->force_initial_value(newstate);
+    if (!SIM::bypass_ok
+	|| _lastchangenode != OUTNODE
+	|| SIM::phase != SIM::pTRAN) {
+      LOGICVAL future_state = c->logic_eval(&ns[BEGIN_IN]);
+      //		         ^^^^^^^^^^
+      {if ((ns[OUTNODE]->is_unknown())
+	  && (SIM::phase == SIM::pINIT_DC || SIM::phase == SIM::pDC_SWEEP)) {
+	ns[OUTNODE]->force_initial_value(future_state);
 	/* This happens when initial DC is digital.
 	 * Answers could be wrong if order in netlist is reversed 
 	 */
-      }else{
-	switch (newstate) {
+      }else if (future_state != ns[OUTNODE]->lv()) {
+	assert(future_state != lvUNKNOWN);
+	switch (future_state) {
 	case lvSTABLE0:	/*nothing*/		break;
-	case lvRISING:  newstate=lvSTABLE0;	break;
-	case lvFALLING: newstate=lvSTABLE1;	break;
+	case lvRISING:  future_state=lvSTABLE0;	break;
+	case lvFALLING: future_state=lvSTABLE1;	break;
 	case lvSTABLE1:	/*nothing*/		break;
-	case lvUNKNOWN: untested(); /*nothing*/	break;
+	case lvUNKNOWN: unreachable();		break;
 	}
-	if (newstate.lv_future() != ns[OUTNODE]->lv_future()) {
-	  ns[OUTNODE]->set_event(m->delay);
-	  //assert(newstate == ns[OUTNODE]->lv_future());
+	/* This handling of rising and falling may seem backwards.
+	 * These states occur when the value has been contaminated 
+	 * by another pending action.  The "old" value is the
+	 * value without this contamination.
+	 * This code is planned for replacement as part of VHDL/Verilog
+	 * conversion, so the kluge stays in for now.
+	 */
+	assert(future_state.lv_old() == future_state.lv_future());
+	if (ns[OUTNODE]->lv() == lvUNKNOWN
+	    || future_state.lv_future() != ns[OUTNODE]->lv_future()) {
+	  ns[OUTNODE]->set_event(m->delay, future_state);
+	  //assert(future_state == ns[OUTNODE]->lv_future());
 	  if (_lastchangenode == OUTNODE) {
-	    untested();
+	    unreachable();
 	    error(bDANGER, "%s:%u:%g non-event state change\n",
 		  long_label().c_str(), STATUS::iter[iTOTAL], SIM::time0);
 	  }
@@ -407,6 +423,11 @@ void DEV_LOGIC::tr_unload()
   tr_unload_passive();
 }
 /*--------------------------------------------------------------------------*/
+void DEV_LOGIC::ac_alloc_matrix()
+{
+  subckt().ac_alloc_matrix();
+}
+/*--------------------------------------------------------------------------*/
 void DEV_LOGIC::ac_begin()
 {
   untested();
@@ -420,13 +441,13 @@ void DEV_LOGIC::ac_begin()
 double DEV_LOGIC::tr_probe_num(CS& what)const
 {
   untested();
-  return nstat[_n[OUTNODE].m].tr_probe_num(what);
+  return nstat[_n[OUTNODE].m_()].tr_probe_num(what);
 }
 /*--------------------------------------------------------------------------*/
 XPROBE DEV_LOGIC::ac_probe_ext(CS& what)const
 {
   untested();
-  return nstat[_n[OUTNODE].m].ac_probe_ext(what);
+  return nstat[_n[OUTNODE].m_()].ac_probe_ext(what);
 }
 /*--------------------------------------------------------------------------*/
 bool COMMON_LOGIC::operator==(const COMMON_COMPONENT& x)const
