@@ -1,4 +1,4 @@
-/*$Id: d_res.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_res.cc,v 23.1 2002/11/06 07:47:50 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -44,7 +44,7 @@ void DEV_RESISTANCE::precalc()
 /*--------------------------------------------------------------------------*/
 void DEV_RESISTANCE::dc_begin()
 {
-  if (!has_tr_eval()){
+  if (!using_tr_eval()){
     assert(_y0.f0 == LINEAR);
     assert(_y0.f1 == value() || _y0.f1 == OPT::shortckt);
     assert(conchk(_m0.c1, 1./_y0.f1));
@@ -57,7 +57,7 @@ void DEV_RESISTANCE::dc_begin()
 /*--------------------------------------------------------------------------*/
 bool DEV_RESISTANCE::do_tr()
 {
-  {if (has_tr_eval()){
+  {if (using_tr_eval()){
     _m0.x = tr_involts_limited();
     _y0.x = _m0.c0 + _m0.c1 * _m0.x;
     tr_eval();
