@@ -1,4 +1,4 @@
-/*$Id: d_res.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_res.h,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -34,16 +34,19 @@ private: // override virtual
   char	   id_letter()const	{return 'R';}
   const char* dev_type()const	{return "resistor";}
   int	   max_nodes()const	{return 2;}
-  int	   num_nodes()const	{return 2;}
   int	   min_nodes()const	{return 2;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 2;}
+  int	   net_nodes()const	{return 2;}
   bool	   is_1port()const	{return true;}
   CARD*	   clone()const		{return new DEV_RESISTANCE(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   void	   precalc();
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_passive();}
   void	   dc_begin();
   void	   tr_begin()		{dc_begin();}
   void	   tr_restore()		{dc_begin();}
@@ -56,15 +59,17 @@ private: // override virtual
   //double tr_review();		//CARD/nothing
   //void   tr_accept();		//CARD/nothing
   void	   tr_unload()		{tr_unload_passive();}
-  //double tr_amps()const	//ELEMENT
   double   tr_involts()const	{return tr_outvolts();}
   double   tr_involts_limited()const {return tr_outvolts_limited();}
+  //double tr_amps()const	//ELEMENT
   //double tr_probe_num(CS&)const;//ELEMENT
 
+  void	   ac_alloc_matrix()	{ac_alloc_matrix_passive();}
   void     ac_begin()           {_ev = _y0.f1; _acg = 1. / _ev;} 
   void	   do_ac();
   void	   ac_load()		{ac_load_passive();}
   COMPLEX  ac_involts()const	{return ac_outvolts();}
+  //COMPLEX ac_amps()const;	//ELEMENT
   //XPROBE ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
