@@ -1,4 +1,4 @@
-/*$Id: d_subckt.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_subckt.h,v 24.12 2003/12/14 01:58:35 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -25,7 +25,7 @@
 #define D_SUBCKT_H
 #include "e_subckt.h"
 /*--------------------------------------------------------------------------*/
-#define NODESPERSUBCKT 1000
+#define NODESPERSUBCKT 4000
 #define PORTS_PER_SUBCKT 100
 /*--------------------------------------------------------------------------*/
 class DEV_SUBCKT : public BASE_SUBCKT {
@@ -38,8 +38,10 @@ private: // override virtual
   char		id_letter()const	{return 'X';}
   const char*	dev_type()const		{untested(); return "subckt";}
   int		max_nodes()const	{return PORTS_PER_SUBCKT;}
-  int		num_nodes()const	{return port_count();}
   int		min_nodes()const	{return 1;}
+  int		out_nodes()const	{return _net_nodes;}
+  int		matrix_nodes()const	{return 0;}
+  int		net_nodes()const	{return _net_nodes;}
   CARD*		clone()const		{return new DEV_SUBCKT(*this);}
   void		parse(CS&);
   void		print(OMSTREAM&,int)const;
@@ -48,8 +50,9 @@ private: // override virtual
 public:
   static int	count()			{return _count;}
 private:
-  static int	_count;
+  int		_net_nodes;
   node_t	_nodes[PORTS_PER_SUBCKT];
+  static int	_count;
 };
 /*--------------------------------------------------------------------------*/
 class COMMON_SUBCKT : public COMMON_COMPONENT {
@@ -77,8 +80,10 @@ private: // override virtual
   char		id_letter()const	{return '\0';}
   const char*   dev_type()const		{untested(); return "";}
   int		max_nodes()const	{return PORTS_PER_SUBCKT;}
-  int		num_nodes()const	{return port_count();}
   int		min_nodes()const	{return 1;}
+  int		out_nodes()const	{return 0;}
+  int		matrix_nodes()const	{return 0;}
+  int		net_nodes()const	{return _net_nodes;}
   CARD*		clone()const	{untested(); return new MODEL_SUBCKT(*this);}
   void		parse(CS&);
   void		print(OMSTREAM&,int)const;
@@ -87,6 +92,7 @@ private: // override virtual
 public:
   static int	count()			{return _count;}
 private:
+  int		_net_nodes;
   node_t	_nodes[PORTS_PER_SUBCKT];
   static int	_count;
 };
