@@ -1,4 +1,4 @@
-/*$Id: d_trln.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_trln.cc,v 24.5 2003/04/27 01:05:05 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -81,7 +81,6 @@ bool COMMON_TRANSLINE::operator==(const COMMON_COMPONENT& x)const
     && G == p->G
     && is_equal(x);
   if (rv) {
-    untested();
     {for (int i=0; i<NUM_INIT_COND; ++i) {
       rv &= ic[i] == p->ic[i];
     }}
@@ -93,17 +92,20 @@ void COMMON_TRANSLINE::parse(CS& cmd)
 {
   int here = cmd.cursor();
   do{
-    get(cmd, "LEN", &len);
-    get(cmd, "Mult",&len);
-    get(cmd, "R",   &R);
-    get(cmd, "L",   &L);
-    get(cmd, "G",   &G);
-    get(cmd, "C",   &C);
-    get(cmd, "Z0",  &z0);
-    get(cmd, "Zo",  &z0);
-    get(cmd, "TD",  &td);
-    get(cmd, "Freq",&f,  mPOSITIVE);
-    get(cmd, "Nl",  &nl, mPOSITIVE);
+    0
+      || get(cmd, "LEN",  &len)
+      || get(cmd, "Mult", &len)
+      || get(cmd, "R",    &R)
+      || get(cmd, "L",    &L)
+      || get(cmd, "G",    &G)
+      || get(cmd, "C",    &C)
+      || get(cmd, "Z0",   &z0)
+      || get(cmd, "Zo",   &z0)
+      || get(cmd, "Delay",&td)
+      || get(cmd, "TD",   &td)
+      || get(cmd, "Freq", &f,  mPOSITIVE)
+      || get(cmd, "Nl",   &nl, mPOSITIVE)
+      ;
     if (cmd.pmatch("Ic")) {
       untested();
       icset = true;
@@ -116,28 +118,27 @@ void COMMON_TRANSLINE::parse(CS& cmd)
   cmd.check(bWARNING, "what's this?");
 
   {if (td != NOT_INPUT) {
-    untested();
     real_td = len * td;
     // have td.  check for conflicts.
-    {if (f != NOT_INPUT) {
+    if (f != NOT_INPUT) {
       {if (!conchk(td, nl/f, OPT::vntol)) {
 	untested();
 	cmd.warn(bDANGER, 0, "td, f&nl conflict.  using td");
       }else{
 	untested();
       }}
-    }else{
-      untested();
-    }}
+    }
   }else if (f != NOT_INPUT) {
     // try to calculate td by nl/f
     real_td = len * nl / f;      
   }else if (L != NOT_INPUT && C != NOT_INPUT) {
     untested();
     real_td = len * sqrt(L * C);
+  }else if (real_td == NOT_INPUT) {
+    untested();
+    cmd.warn(bDANGER, 0, "can't determine length");
   }else{
     untested();
-    cmd.warn(bERROR, 0, "can't determine length, giving up");
   }}
 
   {if (z0 != NOT_INPUT) {
@@ -147,12 +148,10 @@ void COMMON_TRANSLINE::parse(CS& cmd)
       cmd.warn(bDANGER, 0, "redundant specification both Z0 and LC, using Z0");
     }
   }else{
-    untested();
     {if (L != NOT_INPUT && C != NOT_INPUT) {
       untested();
       real_z0 = sqrt(L / C);
     }else{
-      untested();
       assert(default_z0 == 50.);
       cmd.warn(bDANGER, 0, "can't determine Z0, assuming 50");
       real_z0 = default_z0;
@@ -220,7 +219,7 @@ void DEV_TRANSLINE::print(OMSTREAM& o, int)const
   assert(c);
 
   o << short_label();
-  printnodes(o, num_nodes());
+  printnodes(o);
   c->print(o);
 }
 /*--------------------------------------------------------------------------*/
@@ -232,6 +231,21 @@ void DEV_TRANSLINE::precalc()
   _reflect.set_delay(c->real_td);
 }
 /*--------------------------------------------------------------------------*/
+void DEV_TRANSLINE::tr_alloc_matrix()
+{
+  extern NODE* nstat; // yuck
+  
+  aa.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  aa.iwant(_n[IN1].m_(), _n[IN2].m_());
+  lu.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  lu.iwant(_n[IN1].m_(), _n[IN2].m_());
+
+  nstat[_n[OUT1].m_()].set_needs_analog();
+  nstat[_n[OUT2].m_()].set_needs_analog();
+  nstat[_n[IN1].m_()].set_needs_analog();
+  nstat[_n[IN2].m_()].set_needs_analog();
+}
+/*--------------------------------------------------------------------------*/
 /* first setup, initial dc, empty the lines
  */
 void DEV_TRANSLINE::tr_begin()
@@ -276,8 +290,8 @@ void DEV_TRANSLINE::tr_load()
     const COMMON_TRANSLINE* 
       c = prechecked_cast<const COMMON_TRANSLINE*>(common());
     assert(c);
-    aa.load_symmetric(_n[OUT1].m, _n[OUT2].m, 1/c->real_z0);
-    aa.load_symmetric(_n[IN1].m,  _n[IN2].m,  1/c->real_z0);
+    aa.load_symmetric(_n[OUT1].m_(), _n[OUT2].m_(), 1/c->real_z0);
+    aa.load_symmetric(_n[IN1].m_(),  _n[IN2].m_(),  1/c->real_z0);
     lvf = _if0;
     lvr = _ir0;
   }else{
@@ -285,23 +299,22 @@ void DEV_TRANSLINE::tr_load()
     lvr = dn_diff(_ir0, _ir1);
   }}
   if (lvf != 0.) {
-    {if (_n[OUT1].m != 0) {
+    {if (_n[OUT1].m_() != 0) {
       _n[OUT1].i() += lvf;
     }else{
       untested();
     }}
-    if (_n[OUT2].m != 0) {
-      untested();
+    if (_n[OUT2].m_() != 0) {
       _n[OUT2].i() -= lvf;
     }
   }
   if (lvr != 0.) {
-    {if (_n[IN1].m != 0) {
+    {if (_n[IN1].m_() != 0) {
       _n[IN1].i() += lvr;
     }else{
       untested();
     }}
-    if (_n[IN2].m != 0) {
+    if (_n[IN2].m_() != 0) {
       untested();
       _n[IN2].i() -= lvr;
     }
@@ -353,10 +366,10 @@ void DEV_TRANSLINE::do_ac()
 /*--------------------------------------------------------------------------*/
 void DEV_TRANSLINE::ac_load()
 {
-  acx.load_symmetric(_n[OUT1].m, _n[OUT2].m, _y11);
-  acx.load_symmetric(_n[IN1].m,  _n[IN2].m,  _y11);
-  acx.load_asymmetric(_n[OUT1].m,_n[OUT2].m, _n[IN2].m,  _n[IN1].m,  _y12);
-  acx.load_asymmetric(_n[IN1].m, _n[IN2].m,  _n[OUT2].m, _n[OUT1].m, _y12);
+  acx.load_symmetric(_n[OUT1].m_(), _n[OUT2].m_(), _y11);
+  acx.load_symmetric(_n[IN1].m_(),  _n[IN2].m_(),  _y11);
+  acx.load_asymmetric(_n[OUT1].m_(),_n[OUT2].m_(), _n[IN2].m_(),  _n[IN1].m_(),  _y12);
+  acx.load_asymmetric(_n[IN1].m_(), _n[IN2].m_(),  _n[OUT2].m_(), _n[OUT1].m_(), _y12);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
