@@ -1,4 +1,4 @@
-/*$Id: d_trln.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_trln.h,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -73,22 +73,25 @@ private: // override virtual
   char		id_letter()const	{return 'T';}
   const char*	dev_type()const		{untested(); return "tline";}
   int		max_nodes()const	{return 4;}
-  int		num_nodes()const	{return 4;}
   int		min_nodes()const	{return 4;}
+  int		out_nodes()const	{return 4;}
+  int		matrix_nodes()const	{return 4;}
+  int		net_nodes()const	{return 4;}
   CARD*		clone()const	{untested();return new DEV_TRANSLINE(*this);}
   void		parse(CS&);
   void		print(OMSTREAM&,int)const;
-  //void	expand();		//CARD/nothing
+  //void	expand();		//COMPONENT
   //void	map_nodes();		//ELEMENT
   void		precalc();
 
+  void		tr_alloc_matrix();
   void		dc_begin()		{untested();}
   void		tr_begin();
   //void	tr_restore();		//CARD/nothing
   void		dc_advance()		{tr_advance();}
   void		tr_advance();
   bool		tr_needs_eval()	{return (_if0 != _if1  ||  _ir0 != _ir1);}
-  void		tr_queue_eval()	{if(tr_needs_eval()){q_eval();}}
+  //void	tr_queue_eval()		//ELEMENT
   bool		do_tr();
   void		tr_load();
   double	tr_review();
@@ -100,6 +103,7 @@ private: // override virtual
 			{unreachable(); return volts_limited(_n[IN1],_n[IN2]);}
   //double	tr_probe_num(CS&)const;	//ELEMENT wrong???
 
+  void		ac_alloc_matrix()	{ac_alloc_matrix_extended();}
   //void	ac_begin();		//CARD/nothing
   void		do_ac();
   void		ac_load();
