@@ -1,4 +1,4 @@
-/*$Id: d_vcr.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_vcr.h,v 24.20 2004/01/18 07:42:51 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -35,16 +35,19 @@ private: // override virtual
   char	   id_letter()const	{return '\0';}
   const char* dev_type()const	{return "vcr";}
   int	   max_nodes()const	{return 4;}
-  int	   num_nodes()const	{untested(); return 4;}
   int	   min_nodes()const	{return 4;}
+  int	   out_nodes()const	{return 2;}
+  int	   matrix_nodes()const	{return 4;}
+  int	   net_nodes()const	{return 4;}
   bool	   is_2port()const	{return true;}
   CARD*	   clone()const		{untested(); return new DEV_VCR(*this);}
   //void   parse(CS&);		//ELEMENT
   //void   print(OMSTREAM,int)const; //ELEMENT
-  //void   expand();		//CARD/nothing
+  //void   expand();		//COMPONENT
   //void   map_nodes();		//ELEMENT
   void	   precalc();
 
+  void	   tr_alloc_matrix()	{tr_alloc_matrix_extended();}
   //void   dc_begin();		//CARD/nothing
   //void   tr_begin();		//CARD/nothing
   //void   tr_restore();	//CARD/nothing
@@ -57,16 +60,18 @@ private: // override virtual
   //double tr_review();		//CARD/nothing
   //void   tr_accept();		//CARD/nothing
   void	   tr_unload()	{untested(); tr_unload_shunt(); tr_unload_active();}
-  //double tr_amps()const	//ELEMENT
   double tr_involts()const
 		{untested(); return dn_diff(_n[IN1].v0(), _n[IN2].v0());}
   double   tr_involts_limited()const {return volts_limited(_n[IN1],_n[IN2]);}
+  double   tr_amps()const	{untested(); return ELEMENT::tr_amps();}
   //double tr_probe_num(CS&)const;//ELEMENT
 
+  void	   ac_alloc_matrix()	{ac_alloc_matrix_extended();}
   void	   ac_begin();
   void	   do_ac();
   void	   ac_load()		{ac_load_loss(); ac_load_active();}
   COMPLEX  ac_involts()const {untested(); return _n[IN1].vac()-_n[IN2].vac();}
+  COMPLEX  ac_amps()const	{untested(); return ELEMENT::ac_amps();}
   //XPROBE ac_probe_ext(CS&)const;//ELEMENT
 };
 /*--------------------------------------------------------------------------*/
