@@ -1,4 +1,4 @@
-/*$Id: d_vcvs.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_vcvs.cc,v 24.9 2003/08/24 03:04:33 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -40,18 +40,18 @@ void DEV_VCVS::precalc()
 void DEV_VCVS::dc_begin()
 {
   _loss1 = _loss0 = 1./OPT::shortckt;
-  if (!has_tr_eval()){
+  if (!using_tr_eval()){
     assert(_y0.f0 == LINEAR);
     assert(_y0.f1 == value());
-    _m0.c1 = -_loss0 * _y0.f1;
-    assert(_m0.c0 == 0.);
     assert(_m1 == _m0);
+    assert(_m0.c0 == 0.);
+    _m0.c1 = -_loss0 * _y0.f1;
   }
 }
 /*--------------------------------------------------------------------------*/
 bool DEV_VCVS::do_tr()
 {
-  {if (has_tr_eval()){
+  {if (using_tr_eval()){
     _m0.x = tr_involts_limited();
     _y0.x = _m0.x;
     tr_eval();
