@@ -1,4 +1,4 @@
-/*$Id: d_vs.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: d_vs.cc,v 24.21 2004/01/21 15:58:10 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -42,25 +42,39 @@ void DEV_VS::precalc()
 void DEV_VS::dc_begin()
 {
   _loss1 = _loss0 = 1./OPT::shortckt;
-  if (!has_tr_eval()){
-    set_limit(value());
+  if (!using_tr_eval()){
+    {if (_n[OUT2].m_() == 0) {
+      set_limit(value());
+    }else if (_n[OUT1].m_() == 0) {
+      untested();
+      set_limit(-value());
+    }else{
+      // BUG: don't set limit
+      untested();
+    }}
     assert(_y0.x == 0.);
     assert(_y0.f0 == 0.);
     assert(_y0.f1 == value());
-    assert(_m0.x == 0.);
-    _m0.c0 = -_loss0 * _y0.f1;
-    assert(_m0.c1 == 0.);
     assert(_m1 == _m0);
+    assert(_m0.x == 0.);
+    assert(_m0.c1 == 0.);
+    _m0.c0 = -_loss0 * _y0.f1;
   }
 }
 /*--------------------------------------------------------------------------*/
 bool DEV_VS::do_tr()
 {
   assert(_m0.x == 0.);
-  {if (has_tr_eval()){
+  {if (using_tr_eval()){
     _y0.x = SIM::time0;
     tr_eval();
-    set_limit(_y0.f1);
+    {if (_n[OUT2].m_() == 0) {
+      set_limit(_y0.f1);
+    }else if (_n[OUT1].m_() == 0) {
+      set_limit(-_y0.f1);
+    }else{
+      // BUG: don't set limit
+    }}
     store_values();
     q_load();
     _m0.c0 = -_loss0 * _y0.f1;
@@ -85,6 +99,7 @@ void DEV_VS::do_ac()
     ac_eval();
     _acg = -_loss0 * _ev;
   }else{
+    untested();
     assert(_acg == 0.);
   }}
   ac_load();
