@@ -1,4 +1,4 @@
-/*$Id: e_card.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: e_card.h,v 24.12 2003/12/14 01:58:35 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -38,12 +38,10 @@ private:
   int		_evaliter;	// model eval iteration number
   CARD_LIST	_subckt;
   CARD*		_owner;
-public: //insert, s__init, s__map
+public:
   node_t*	_n;
 private:
   double	_value;		// value, for simple parts
-  int		_port_count;	// actual number of port nodes
-  int		_inode_count;	// actual number of internal nodes
   bool		_constant;	// eval stays the same every iteration
   //--------------------------------------------------------------------
 protected:   				// traversal functions
@@ -57,18 +55,20 @@ public:					// virtuals. -- the important stuff
   virtual void	 expand()		{}
   virtual void	 map_nodes()		{}
   virtual void	 precalc()		{}
+  virtual void	 tr_alloc_matrix()	{}
   virtual void	 dc_begin()		{}
   virtual void	 tr_begin()		{}
   virtual void	 tr_restore()		{}
   virtual void	 dc_advance()		{}
   virtual void	 tr_advance()		{}
-  virtual bool	 tr_needs_eval()	{untested(); return false;}
+  virtual bool	 tr_needs_eval()	{return false;}
   virtual void	 tr_queue_eval()	{}
   virtual bool	 do_tr()		{return true;};
   virtual void	 tr_load()		{}
   virtual double tr_review()		{return NEVER;}
   virtual void	 tr_accept()		{}
   virtual void	 tr_unload()		{}
+  virtual void	 ac_alloc_matrix()	{}
   virtual void	 ac_begin()		{}
   virtual void	 do_ac()		{}
   virtual void	 ac_load()		{}
@@ -86,12 +86,18 @@ public:
   //--------------------------------------------------------------------
 public:					// query functions.
   static double	probe(const CARD*,const std::string&);
-  int		connects_to(int node)const;
+  int		connects_to(const node_t& node)const;
   //--------------------------------------------------------------------
-protected:				// query functions. deferred inline
+public:					// query functions. deferred inline
   bool	evaluated();
   //--------------------------------------------------------------------
 public:					// query functions. virtual constant
+  //virtual int	max_nodes()const	// in component
+  //virtual int	min_nodes()const	// in component
+  virtual int	out_nodes()const	{return 0;}
+  virtual int	matrix_nodes()const	{return 0;}
+  virtual int	net_nodes()const	{return 0;}
+  //virtual int	int_nodes()const	// in component
   virtual bool	is_1port()const		{return false;}
   virtual bool	is_2port()const		{return false;}
   virtual bool	is_source()const	{return false;}
@@ -102,35 +108,26 @@ public:					// query functions.
   CARD_LIST&	     subckt()		{return _subckt;}
   const CARD_LIST&   subckt()const	{return _subckt;}
   double	     value()const	{return _value;}
-  int		     port_count()const	{return _port_count;}
-  int		     inode_count()const	{return _inode_count;}
   const std::string  long_label()const; /* virtual */
   CARD*		     owner()const	{return _owner;}
   int		     evaliter()const	{return STATUS::iter[iTOTAL];}
   bool		     constant()const	{return _constant;}
   //--------------------------------------------------------------------
-protected:				// modifiers.
+public:					// modifiers.
   virtual void	set_slave()		{untested(); subckt().set_slave();}
+protected:
   virtual void  set_value(double v)	{_value = v;}
 public:
   virtual void  set_value(double v, COMMON_COMPONENT*)
 					{untested(); set_value(v);}
   double* set_value()		{return &_value;}
 protected:
-  void	  parse_label(CS&);
-  void	  parse_Label(CS&);
+  void	  parse_label(CS&);	// as it says
+  void	  parse_Label(CS&);	// as above, but capitalize the first letter
 public:
   void	  set_owner(CARD* o)	{assert(!_owner||_owner==o); _owner=o;}
   void	  set_constant(bool c)	{_constant = c;}
-protected:
-  void	  set_port_count(int c)  {_port_count = c;}
-  void	  set_inode_count(int c) {_inode_count = c;}
   //--------------------------------------------------------------------
-  // a very bad way to do parameter passing between the device and expression
-public:
-  static double initial_condition;
-  //--------------------------------------------------------------------
-  friend class CARD_LIST;
   friend CARD_LIST::fat_iterator findbranch(CS&,CARD_LIST::fat_iterator);
 };
 /*--------------------------------------------------------------------------*/
