@@ -1,4 +1,4 @@
-/*$Id: e_cardlist.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: e_cardlist.cc,v 22.21 2002/10/06 07:21:50 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -29,12 +29,12 @@
 /*--------------------------------------------------------------------------*/
 CARD_LIST::iterator CARD_LIST::find(const std::string& short_name)
 {
-  return find_ptr(begin(), end(), short_name);
+  return notstd::find_ptr(begin(), end(), short_name);
 }
 /*--------------------------------------------------------------------------*/
 CARD_LIST::const_iterator CARD_LIST::find(const std::string& short_name)const
 {
-  return find_ptr(begin(), end(), short_name);
+  return notstd::find_ptr(begin(), end(), short_name);
 }
 /*--------------------------------------------------------------------------*/
 CARD_LIST& CARD_LIST::erase(iterator ci)
@@ -97,6 +97,17 @@ CARD_LIST& CARD_LIST::precalc()
   return *this;
 }
 /*--------------------------------------------------------------------------*/
+/* tr_alloc_matrix: allocate solution matrix
+ * also sets some flags for mixed-mode
+ */
+CARD_LIST& CARD_LIST::tr_alloc_matrix()
+{
+  for (iterator ci=begin(); ci!=end(); ++ci) {
+    (**ci).tr_alloc_matrix();
+  }
+  return *this;
+}
+/*--------------------------------------------------------------------------*/
 /* dc_begin: first pass on a new DC simulation
  */
 CARD_LIST& CARD_LIST::dc_begin()
@@ -238,6 +249,16 @@ CARD_LIST& CARD_LIST::tr_unload()
   return *this;
 }
 /*--------------------------------------------------------------------------*/
+/* ac_alloc_matrix: allocate solution matrix
+ */
+CARD_LIST& CARD_LIST::ac_alloc_matrix()
+{
+  for (iterator ci=begin(); ci!=end(); ++ci) {
+    (**ci).ac_alloc_matrix();
+  }
+  return *this;
+}
+/*--------------------------------------------------------------------------*/
 /* ac_begin: first pass on a new ac simulation
  */
 CARD_LIST& CARD_LIST::ac_begin()
