@@ -1,4 +1,4 @@
-/*$Id: e_compon.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: e_compon.h,v 24.10 2003/10/18 05:14:15 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -85,9 +85,6 @@ public:
 	  bool	      has_model()const	{return _model;}
 
   bool is_equal(const COMMON_COMPONENT&)const;
-private:
-  COMMON_COMPONENT* attach() {++_attach_count; return this;}
-  int detach()		     {assert(_attach_count>0);return --_attach_count;}
 protected:
   double	_tnom;
 private:
@@ -118,16 +115,18 @@ protected:
 	     ~COMPONENT()		{subckt().destroy(); detach_common();}
 public:
   virtual const char* dev_type()const = 0;
-  virtual int	      max_nodes()const = 0;
-  virtual int	      num_nodes()const = 0;
-  virtual int	      min_nodes()const = 0;
+  virtual int	max_nodes()const = 0;
+  virtual int	min_nodes()const = 0;
+  virtual int	int_nodes()const	{return 0;}
 protected: // override virtual
   void  expand();
   bool	is_device()const		{return true;}
   void  map_nodes();
+  void  tr_alloc_matrix();
+  void  ac_alloc_matrix();
 protected: // not virtual
   int	parse_nodes(CS&,int,int,int=0);
-  void	printnodes(OMSTREAM&,int,int=0)const;
+  void	printnodes(OMSTREAM&)const;
 
   const MODEL_CARD* attach_model()const	
 		{return (has_common() ? _common->attach_model(this) : 0);}
@@ -142,8 +141,10 @@ protected: // not virtual
   void	expandsubckt(const std::string& modelname);
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // list and queue management
-  bool	is_q_for_eval() {return (_queued_for_eval>=STATUS::iter[iTOTAL]);}
-  bool	qfe();
+  bool	is_q_for_eval() {return (_q_for_eval>=STATUS::iter[iTOTAL]);}
+  void	mark_q_for_eval()	 {_q_for_eval = STATUS::iter[iTOTAL];}
+  void	mark_always_q_for_eval() {_q_for_eval = INT_MAX;}
+  // mark_as...  doesn't queue it, just marks it as queued.  It might lie.
   void	q_eval();
   void	q_load()	{SIM::loadq.push_back(this);}
   void	q_accept()	{SIM::acceptq.push_back(this);}
@@ -153,13 +154,13 @@ public:
   virtual void set_parameters(const std::string& Label, CARD* Parent,
 			      COMMON_COMPONENT* Common, double Value,
 			      int state_count, double state[],
-			      int port_count, const node_t nodes[]);
-  void	set_slave()	    {_queued_for_eval = INT_MAX; subckt().set_slave();}
+			      int node_count, const node_t nodes[]);
+  void	set_slave()	{mark_always_q_for_eval(); subckt().set_slave();}
   void	set_value(double v) {CARD::set_value(v);}
   void	set_value(double v, COMMON_COMPONENT* c);
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // querys
-  bool	is_slave()const	  {untested(); return (_queued_for_eval==INT_MAX);}
+  bool	is_slave()const	  {untested(); return (_q_for_eval==INT_MAX);}
   bool	has_common()const {return _common;}
   // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   // data access
@@ -169,24 +170,16 @@ private:
   COMMON_COMPONENT* _common;
 private:
   bool _converged;	// convergence status
-  int  _queued_for_eval;
+  int  _q_for_eval;
 };
 /*--------------------------------------------------------------------------*/
-/*--------------------------------------------------------------------------*/
-inline bool COMPONENT::qfe()
-{
-  {if (is_q_for_eval()){
-    unreachable();
-    return true;
-  }else{
-    _queued_for_eval=STATUS::iter[iTOTAL];
-    return false;
-  }}
-}
-/*--------------------------------------------------------------------------*/
+/* q_eval: queue this device for evaluation on the next pass,
+ * with a check against doing it twice.
+ */
 inline void COMPONENT::q_eval()
 {
-  {if(!qfe()){
+  {if(!is_q_for_eval()) {
+    mark_q_for_eval();
     SIM::evalq_uc->push_back(this);
   }else{
     unreachable();
