@@ -1,4 +1,4 @@
-/*$Id: e_elemnt.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: e_elemnt.cc,v 24.19 2004/01/11 23:02:30 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -34,7 +34,6 @@ ELEMENT::ELEMENT()
    _loss0(0.),
    _loss1(0.),
    _acg(0.),
-   _method_u(meUNKNOWN),
    _y0(),
    _y1(),
    _y2(),
@@ -54,7 +53,6 @@ ELEMENT::ELEMENT(const ELEMENT& p)
    _loss0(p._loss0),
    _loss1(p._loss1),
    _acg(0.),
-   _method_u(p._method_u),
    _y0(),
    _y1(),
    _y2(),
@@ -108,16 +106,18 @@ void ELEMENT::parse(CS& cmd)
   // commons attached to it.  Try to reduce its complexity.
   // "c->deflate()" may return "c" or some simplification of "c".
   COMMON_COMPONENT* dc = c->deflate(); // dc == deflated_common
+
   EVAL_BM_VALUE* dvc = dynamic_cast<EVAL_BM_VALUE*>(dc);  
   {if (dvc && !dvc->has_ext_args()) {
     set_value(dvc->value());
+    delete c;
   }else{
     attach_common(dc);
+    if (dc != c) {
+      delete c;
+    }
   }}
-  if (dc != c) {
-    delete c;
-  }
-
+  
   cmd.check(bDANGER, "what's this?");
 }
 /*--------------------------------------------------------------------------*/
@@ -127,7 +127,7 @@ void ELEMENT::print(OMSTREAM& where, int /*detail*/)const
     where << '.' << dev_type() << ' ';
   }
   where << short_label();
-  printnodes(where, num_nodes());
+  printnodes(where);
   if (!has_common() || value() != 0) {
     where << ' ' << value();
   }
@@ -137,6 +137,106 @@ void ELEMENT::print(OMSTREAM& where, int /*detail*/)const
   where << '\n';
 }
 /*--------------------------------------------------------------------------*/
+void ELEMENT::tr_alloc_matrix_passive()
+{
+  assert(matrix_nodes() == 2);
+  assert(is_device());
+  //assert(!subckt().exists()); ok for subckt to exist for logic
+  assert(_n[OUT1].m_() != INVALID_NODE);
+  assert(_n[OUT2].m_() != INVALID_NODE);
+  aa.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  lu.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  extern NODE* nstat; // yuck
+  nstat[_n[OUT1].m_()].set_needs_analog();
+  nstat[_n[OUT2].m_()].set_needs_analog();
+}
+/*--------------------------------------------------------------------------*/
+void ELEMENT::tr_alloc_matrix_active()
+{
+  assert(matrix_nodes() == 4);
+  assert(is_device());
+  assert(!subckt().exists());
+  assert(_n[OUT1].m_() != INVALID_NODE);
+  assert(_n[OUT2].m_() != INVALID_NODE);
+  assert(_n[IN1].m_() != INVALID_NODE);
+  assert(_n[IN2].m_() != INVALID_NODE);
+
+  //aa.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  aa.iwant(_n[OUT1].m_(),_n[IN1].m_());
+  aa.iwant(_n[OUT1].m_(),_n[IN2].m_());
+  aa.iwant(_n[OUT2].m_(),_n[IN1].m_());
+  aa.iwant(_n[OUT2].m_(),_n[IN2].m_());
+  //aa.iwant(_n[IN1].m_(),_n[IN2].m_());
+
+  //lu.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  lu.iwant(_n[OUT1].m_(),_n[IN1].m_());
+  lu.iwant(_n[OUT1].m_(),_n[IN2].m_());
+  lu.iwant(_n[OUT2].m_(),_n[IN1].m_());
+  lu.iwant(_n[OUT2].m_(),_n[IN2].m_());
+  //lu.iwant(_n[IN1].m_(),_n[IN2].m_());
+
+  extern NODE* nstat; // yuck
+  nstat[_n[OUT1].m_()].set_needs_analog();
+  nstat[_n[OUT2].m_()].set_needs_analog();
+  nstat[_n[IN1].m_()].set_needs_analog();
+  nstat[_n[IN2].m_()].set_needs_analog();
+}
+/*--------------------------------------------------------------------------*/
+void ELEMENT::tr_alloc_matrix_extended()
+{
+  extern NODE* nstat; // yuck
+
+  assert(is_device());
+  {if (subckt().exists()) {
+    unreachable();
+    subckt().tr_alloc_matrix();
+  }else{
+    for (int ii = 0;  ii < matrix_nodes();  ++ii) {
+      assert(_n[ii].m_() != INVALID_NODE);
+      if (_n[ii].m_() != 0) {
+	for (int jj = 0;  jj < ii ;  ++jj) {
+	  aa.iwant(_n[ii].m_(),_n[jj].m_());
+	  lu.iwant(_n[ii].m_(),_n[jj].m_());
+	}
+	nstat[_n[ii].m_()].set_needs_analog();
+      }
+    }
+  }}
+}
+/*--------------------------------------------------------------------------*/
+void ELEMENT::ac_alloc_matrix_passive()
+{
+  acx.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+}
+/*--------------------------------------------------------------------------*/
+void ELEMENT::ac_alloc_matrix_active()
+{
+  //acx.iwant(_n[OUT1].m_(),_n[OUT2].m_());
+  acx.iwant(_n[OUT1].m_(),_n[IN1].m_());
+  acx.iwant(_n[OUT1].m_(),_n[IN2].m_());
+  acx.iwant(_n[OUT2].m_(),_n[IN1].m_());
+  acx.iwant(_n[OUT2].m_(),_n[IN2].m_());
+  //acx.iwant(_n[IN1].m_(),_n[IN2].m_());
+}
+/*--------------------------------------------------------------------------*/
+void ELEMENT::ac_alloc_matrix_extended()
+{
+  assert(is_device());
+  {if (subckt().exists()) {
+    unreachable();
+    subckt().ac_alloc_matrix();
+  }else{
+    for (int ii = 0;  ii < matrix_nodes();  ++ii) {
+      assert(_n[ii].m_() != INVALID_NODE);
+      if (_n[ii].m_() != 0) {
+	for (int jj = 0;  jj < ii ;  ++jj) {
+	  acx.iwant(_n[ii].m_(),_n[jj].m_());
+	}
+      }
+    }
+  }}
+}
+/*--------------------------------------------------------------------------*/
 double ELEMENT::tr_amps()const
 {
   return fixzero((_loss0 * tr_outvolts() + _m0.c1 * tr_involts() + _m0.c0),
@@ -160,7 +260,6 @@ double ELEMENT::tr_probe_num(CS& cmd)const
     double p = tr_amps() * tr_outvolts();
     return (p < 0.) ? -p : 0.;
   }else if (cmd.pmatch("INput")) {
-    untested();
     return _y0.x;
   }else if (cmd.pmatch("F")) {
     if (_y0.f0 == LINEAR) {
@@ -211,31 +310,33 @@ double ELEMENT::tr_probe_num(CS& cmd)const
   }}
 }
 /*--------------------------------------------------------------------------*/
+COMPLEX ELEMENT::ac_amps()const
+{
+  assert(!is_source());
+  return (ac_involts() * _acg + ac_outvolts() * _loss0);
+}
+/*--------------------------------------------------------------------------*/
 XPROBE ELEMENT::ac_probe_ext(CS& cmd)const
 {
-  COMPLEX admittance = (is_source()) ? COMPLEX(0.) : _acg;
-  COMPLEX source =     (is_source()) ? _acg : COMPLEX(0.);
+  COMPLEX admittance = (is_source()) ? _loss0 : _acg+_loss0;
 
-  {if (cmd.pmatch("V")) {			/* volts (out) */
+  {if (cmd.pmatch("Vout")) {			/* volts (out) */
     return XPROBE(ac_outvolts());
-  }else if (cmd.pmatch("VI")) {			/* volts (in) */
+  }else if (cmd.pmatch("VIN")) {		/* volts (in) */
     return XPROBE(ac_involts());
   }else if (cmd.pmatch("I")) {			/* amps */
-    return XPROBE(ac_involts() * admittance + source + ac_outvolts() * _loss0);
+    return XPROBE(ac_amps());
   }else if (cmd.pmatch("P")) {			/* complex "power" */
-    COMPLEX i = ac_involts() * admittance + source + ac_outvolts() * _loss0;
-    return XPROBE(ac_outvolts() * conj(i), mtREAL, 10.);
+    return XPROBE(ac_outvolts() * conj(ac_amps()), mtREAL, 10.);
   }else if (cmd.pmatch("NV")) {			/* nominal value */
     untested();
     return XPROBE(value());
   }else if (cmd.pmatch("EV")) {			/* effective value */
     return XPROBE(_ev);
   }else if (cmd.pmatch("Y")) {			/* admittance */
-    untested();
     return XPROBE(admittance, mtREAL);
   }else if (cmd.pmatch("R")) {			/* complex "resistance" */
     {if (admittance == 0.) {
-      untested();
       return XPROBE(DBL_MAX);
     }else{
       return XPROBE(1. / admittance);
