@@ -1,4 +1,4 @@
-/*$Id: e_elemnt.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: e_elemnt.h,v 24.19 2004/01/11 23:02:30 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -45,7 +45,9 @@ protected: // override virtual
   bool	   tr_needs_eval()	{return !constant();}
   void	   tr_queue_eval()	{if(tr_needs_eval()) {q_eval();}}
   void	   map_nodes() {assert(!subckt().exists()); COMPONENT::map_nodes();}
-  
+  void	   tr_alloc_matrix() = 0;
+  void	   ac_alloc_matrix() = 0;
+
 protected: // inline, below
   double   dampdiff(double&, const double&, bool);
 
@@ -76,21 +78,35 @@ protected: // inline, below
 			    COMPLEX value);
 
   bool	   conv_check()const;
+  bool	   using_tr_eval()const;
   bool	   has_tr_eval()const;
   bool	   has_ac_eval()const;
   void	   tr_eval();
   void	   ac_eval();
+#ifdef KNEECHORD
+  int      inverse();      // see inverse.cc
+  void     knee_chord();   // see inverse.cc
+#endif
+
 protected: // in .cc
+  void	   tr_alloc_matrix_passive();
+  void	   tr_alloc_matrix_active();
+  void	   tr_alloc_matrix_extended();
+  void	   ac_alloc_matrix_passive();
+  void	   ac_alloc_matrix_active();
+  void	   ac_alloc_matrix_extended();
+
   double   tr_outvolts()const	{return dn_diff(_n[OUT1].v0(), _n[OUT2].v0());}
   double   tr_outvolts_limited()const{return volts_limited(_n[OUT1],_n[OUT2]);}
   COMPLEX  ac_outvolts()const	{return _n[OUT1].vac() - _n[OUT2].vac();}
   double   tr_probe_num(CS&)const;
   XPROBE   ac_probe_ext(CS&)const;
 
-  virtual  double  tr_amps()const;
   virtual  double  tr_involts()const = 0;
   virtual  double  tr_involts_limited()const = 0;
+  virtual  double  tr_amps()const;
   virtual  COMPLEX ac_involts()const = 0;
+  virtual  COMPLEX ac_amps()const;
 private:
   int      _loaditer;	// load iteration number
   node_t   _nodes[NODES_PER_BRANCH]; // nodes (0,1:out, 2,3:in)
@@ -100,7 +116,6 @@ protected:
   double   _loss0;	// shunt conductance
   double   _loss1;
   COMPLEX  _acg;	// ac admittance matrix values
-  method_t _method_u;	// method to use for this part per user
 public: // commons
   FPOLY1   _y0;		// iteration parameters, new
   FPOLY1   _y1;		// iteration parameters, 1 iter ago
@@ -124,7 +139,7 @@ inline void ELEMENT::tr_load_shunt()
 {
   double d = dampdiff(_loss0, _loss1, true);
   if (d != 0.) {
-    aa.load_symmetric(_n[OUT1].m, _n[OUT2].m, d);
+    aa.load_symmetric(_n[OUT1].m_(), _n[OUT2].m_(), d);
   }
   _loss1 = _loss0;
 }
@@ -140,7 +155,7 @@ inline void ELEMENT::tr_unload_shunt()
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::ac_load_shunt()
 {
-  acx.load_symmetric(_n[OUT1].m, _n[OUT2].m, _loss0);
+  acx.load_symmetric(_n[OUT1].m_(), _n[OUT2].m_(), _loss0);
 }
 /*--------------------------------------------------------------------------*/
  inline void ELEMENT::tr_load_loss()
@@ -164,10 +179,10 @@ inline void ELEMENT::tr_load_source()
 
   double dc0 = dampdiff(_m0.c0, _m1.c0, true);
   if (dc0 != 0.) {
-    if (_n[OUT2].m != 0) {
+    if (_n[OUT2].m_() != 0) {
       _n[OUT2].i() += dc0;
     }
-    if (_n[OUT1].m != 0) {
+    if (_n[OUT1].m_() != 0) {
       _n[OUT1].i() -= dc0;
     }
   }
@@ -187,10 +202,10 @@ inline void ELEMENT::tr_unload_source()
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::ac_load_source()
 {
-  if (_n[OUT2].m != 0) {
+  if (_n[OUT2].m_() != 0) {
     _n[OUT2].iac() += _acg;
   }
-  if (_n[OUT1].m != 0) {
+  if (_n[OUT1].m_() != 0) {
     _n[OUT1].iac() -= _acg;
   }
 }
@@ -199,7 +214,7 @@ inline void ELEMENT::tr_load_passive()
 {
   double d = dampdiff(_m0.c1, _m1.c1, true);
   if (d != 0.) {
-    aa.load_symmetric(_n[OUT1].m, _n[OUT2].m, d);
+    aa.load_symmetric(_n[OUT1].m_(), _n[OUT2].m_(), d);
   }
   tr_load_source();
 }
@@ -215,14 +230,14 @@ inline void ELEMENT::tr_unload_passive()
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::ac_load_passive()
 {
-  acx.load_symmetric(_n[OUT1].m, _n[OUT2].m, _acg);
+  acx.load_symmetric(_n[OUT1].m_(), _n[OUT2].m_(), _acg);
 }
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::tr_load_active()
 {
   double d = dampdiff(_m0.c1, _m1.c1, true);
   if (d != 0.) {
-    aa.load_asymmetric(_n[OUT1].m, _n[OUT2].m, _n[IN1].m, _n[IN2].m, d);
+    aa.load_asymmetric(_n[OUT1].m_(), _n[OUT2].m_(), _n[IN1].m_(), _n[IN2].m_(), d);
   }
   tr_load_source();
 }
@@ -240,7 +255,7 @@ inline void ELEMENT::tr_unload_active()
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::ac_load_active()
 {
-  acx.load_asymmetric(_n[OUT1].m, _n[OUT2].m, _n[IN1].m, _n[IN2].m, _acg);
+  acx.load_asymmetric(_n[OUT1].m_(), _n[OUT2].m_(), _n[IN1].m_(), _n[IN2].m_(), _acg);
 }
 /*--------------------------------------------------------------------------*/
 inline void ELEMENT::tr_load_extended(const node_t& no1, const node_t& no2,
@@ -249,7 +264,7 @@ inline void ELEMENT::tr_load_extended(const node_t& no1, const node_t& no2,
 {
   double d = dampdiff(*value, *old_value, true);
   if (d != 0.) {
-    aa.load_asymmetric(no1.m, no2.m, ni1.m, ni2.m, d);
+    aa.load_asymmetric(no1.m_(), no2.m_(), ni1.m_(), ni2.m_(), d);
   }
   *old_value = *value;
 }
@@ -258,7 +273,7 @@ inline void ELEMENT::ac_load_extended(const node_t& no1, const node_t& no2,
 				      const node_t& ni1, const node_t& ni2,
 				      COMPLEX value)
 {
-  acx.load_asymmetric(no1.m, no2.m, ni1.m, ni2.m, value);
+  acx.load_asymmetric(no1.m_(), no2.m_(), ni1.m_(), ni2.m_(), value);
 }
 /*--------------------------------------------------------------------------*/
 inline bool ELEMENT::conv_check()const
@@ -270,7 +285,12 @@ inline bool ELEMENT::conv_check()const
 /*--------------------------------------------------------------------------*/
 inline bool ELEMENT::has_tr_eval()const
 {
-  return (has_probes() || (has_common() && common()->has_tr_eval()));
+  return (has_common() && common()->has_tr_eval());
+}
+/*--------------------------------------------------------------------------*/
+inline bool ELEMENT::using_tr_eval()const
+{
+  return (has_probes() || has_tr_eval());
 }
 /*--------------------------------------------------------------------------*/
 inline bool ELEMENT::has_ac_eval()const
@@ -282,6 +302,13 @@ inline void ELEMENT::tr_eval()
 {
   {if (has_common() && common()->has_tr_eval()) {
     common()->tr_eval(this);
+#ifdef KNEECHORD
+    switch (OPT::strategy) {
+    case stNEWTON:			break;
+    case stKNEECHORD:	knee_chord();	break;
+    case stSECANT:	incomplete();	break;
+    }
+#endif
   }else{
     // can get here if a simple device has probes
     _y0.f1 = value();
