@@ -1,4 +1,4 @@
-/*$Id: e_storag.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: e_storag.h,v 24.12 2003/12/14 01:58:35 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -29,23 +29,26 @@ enum METHOD {mTRAPGEAR, mEULER, mTRAP, mGEAR, mTRAPEULER};
 /*--------------------------------------------------------------------------*/
 class STORAGE : public ELEMENT {
 protected:
-  explicit STORAGE()			:ELEMENT(),  _method_a(mTRAPGEAR)  {}
-  explicit STORAGE(const STORAGE& p)	:ELEMENT(p), _method_a(p._method_a) {}
+  explicit STORAGE()			
+    :ELEMENT(), _method_u(meUNKNOWN), _method_a(mTRAPGEAR)  {}
+  explicit STORAGE(const STORAGE& p)
+    :ELEMENT(p), _method_u(p._method_u), _method_a(p._method_a) {}
 protected: // override virtual
   void	   precalc();
   void     dc_begin();
   void     tr_begin()		{STORAGE::dc_begin();}
-  void     tr_restore()		{STORAGE::dc_begin();}
+  void     tr_restore();
   void     dc_advance();
   void     tr_advance();
   bool	   tr_needs_eval()	{return true;}
-  void	   tr_queue_eval()	{q_eval();}
+  //void   tr_queue_eval()	//ELEMENT
+  double   tr_review()		{return const_tr_review();}
   double   tr_probe_num(CS&)const;
 protected:
-  double   integrate();
+  double   differentiate();
   double   tr_c_to_g(double c, double g)const;
+  double   const_tr_review()const;
 
-  double   review(double, double)const;
   double   c_mult()const {return _c_mult;}
   double   c_mult_num()const
 		{const double f[] = {1., 1., 2., 1., 1.}; return f[_method_a];}
@@ -54,6 +57,7 @@ protected:
   {const double f[]={1./2., 1./2., 1./12., 1./2., 1./2.}; return f[_method_a];}
 protected:
   enum {_max_order = 2, _keep_time_steps=_max_order+2};
+  method_t _method_u;	/* method to use for this part per user */
   METHOD   _method_a;	/* actual integration method (auto)	*/
   double   _time[_keep_time_steps];
   double   _dt;
@@ -62,10 +66,24 @@ public: // used by commons
   FPOLY1   _q[_keep_time_steps]; /* charge or flux, and deriv.	*/
 protected:
   FPOLY1   _i0;		/* after integration, now		*/
-  FPOLY1   _it1;	/* after integration, 1 time ago	*/
+  double   _it1_f0;	/* after integration, 1 time ago	*/
 protected:
   static METHOD method_select[meNUM_METHODS][meNUM_METHODS];
 };
 /*--------------------------------------------------------------------------*/
+#if 0
+// this works, and saves significant time
+// but possible errors.
+// Errors do not seem significant, but I can't tell without more data.
+// Taking it out to be sure.
+  bool	   tr_needs_eval() {
+    {if (!converged()) {
+      return true;
+    }else{
+      return (STATUS::iter[iSTEP]<2 || !conchk(_y0.x,tr_involts(),OPT::vntol));
+    }}
+  }
+#endif
+/*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
 #endif
