@@ -1,4 +1,4 @@
-/*$Id: io_error.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: io_error.cc,v 22.13 2002/08/01 16:27:25 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -40,7 +40,7 @@ extern JMP_BUF env;
 void error(int badness, const char* fmt, ...)
 {
   if (badness >= OPT::picky) {
-    char buffer[BIGBUFLEN];
+    char buffer[BIGBUFLEN] = "";
     va_list arg_ptr;
     va_start(arg_ptr,fmt);
     vsprintf(buffer,fmt,arg_ptr);
