@@ -1,4 +1,4 @@
-/*$Id: io_out.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: io_out.cc,v 22.3 2002/05/22 06:24:36 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -179,18 +179,15 @@ OMSTREAM & OMSTREAM::operator<<(char chr)
 	fflush(IO::stream[ii]);
       }else if (chr=='\r') {
 	{if (_cpos[ii] == 0) {
-	  untested(); 
 	  suppress = true;
 	}else{
 	  _cpos[ii] = 0;
 	  fflush(IO::stream[ii]);
 	}}
       }}
-      {if (!suppress) {
+      if (!suppress) {
 	fputc(chr,IO::stream[ii]);
-      }else{
-	untested(); 
-      }}
+      }
     }
   }
   return *this;
