@@ -1,4 +1,4 @@
-/*$Id: l_stlextra.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: l_stlextra.h,v 22.21 2002/10/06 07:21:50 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -26,6 +26,18 @@
 #define L_STLEXTRA_H
 #include "md.h"
 /*--------------------------------------------------------------------------*/
+namespace notstd {
+/*--------------------------------------------------------------------------*/
+template <class InputIter, class Size, class OutputIter>
+std::pair<InputIter, OutputIter> copy_n(InputIter first, Size count,
+				   OutputIter result)
+{
+  for ( ; count > 0; --count) {
+    *result++ = *first++;
+  }
+  return std::pair<InputIter, OutputIter>(first, result);
+}
+/*--------------------------------------------------------------------------*/
 /* find_ptr: like the stl find, except that the list contains pointers
    Dereference the pointer in the list, then compare */
 template <class InputIterator, class T>
@@ -44,5 +56,7 @@ inline void to_lower(std::string* s)
   }
 }
 /*--------------------------------------------------------------------------*/
+}
+/*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
 #endif
