@@ -1,4 +1,4 @@
-/*$Id: m_cpoly.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: m_cpoly.h,v 24.5 2003/04/27 01:05:05 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -46,7 +46,7 @@ struct FPOLY1{		/* first order polynomial	*/
   double   f0;		/* the function (c0 + x*f1)	*/
   double   f1;		/* the first derivative		*/
   explicit FPOLY1() : x(0), f0(0), f1(0) {}
-           FPOLY1(const FPOLY1& p) : x(p.x), f0(p.f0), f1(p.f1){untested();}
+           FPOLY1(const FPOLY1& p) : x(p.x), f0(p.f0), f1(p.f1) {}
   explicit FPOLY1(double X,double F0,double F1) : x(X), f0(F0), f1(F1) {}
   explicit FPOLY1(const CPOLY1& p);
 
@@ -58,6 +58,8 @@ struct FPOLY1{		/* first order polynomial	*/
   FPOLY1&  operator+=(const FPOLY1& s)
 		{untested(); assert(x==s.x); f0+=s.f0; f1+=s.f1; return *this;}
   FPOLY1   operator-()const	{untested(); return FPOLY1(x, -f0, -f1);}
+  double   c1()const		{return f1;}
+  double   c0()const		{return (f0 - x * f1);}
 };
 /*--------------------------------------------------------------------------*/
 struct CPOLY1{		/* first order polynomial	*/
@@ -72,20 +74,22 @@ struct CPOLY1{		/* first order polynomial	*/
   bool	   operator==(const CPOLY1& p)const
 				{return (c1==p.c1 && c0==p.c0 && x==p.x);}
   CPOLY1&  operator*=(double s)	{c0*=s; c1*=s; return *this;}
+  double   f1()const		{return c1;}
+  double   f0()const		{return (c0 + x * c1);}
 };
 /*--------------------------------------------------------------------------*/
 inline FPOLY1::FPOLY1(const CPOLY1& p)
   :x(p.x),
-   f1(p.c1)
+   f0(p.f0()),
+   f1(p.f1())
 {
-  f0 = p.c0 + p.x * p.c1;
 }
 /*--------------------------------------------------------------------------*/
 inline CPOLY1::CPOLY1(const FPOLY1& p)
   :x(p.x),
-   c1(p.f1)
+   c0(p.c0()),
+   c1(p.c1())
 {
-  c0 = p.f0 - p.x * p.f1;      
 }
 /*--------------------------------------------------------------------------*/
 inline FPOLY1& FPOLY1::operator*=(const FPOLY1& s)
