@@ -1,4 +1,4 @@
-/*$Id: m_matrix.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: m_matrix.cc,v 22.21 2002/10/06 07:21:50 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -23,6 +23,7 @@
  * Bump and spike - bordered block diagonal pattern
  */
 /*--------------------------------------------------------------------------*/
+#include "l_stlextra.h"
 #include "u_status.h"
 #include "e_node.h"
 #include "m_matrix.h"
@@ -407,7 +408,7 @@ BSMATRIX<T>& BSMATRIX<T>::fbsub(T* x, const T* b, T* c)
       b = x;
   }
   {
-    std::copy_n(b, _size+1, c);
+    notstd::copy_n(b, _size+1, c);
     int ii = 1;
     for (   ; ii <= _size; ++ii){
       if (b[ii] != 0.){
