@@ -1,4 +1,4 @@
-/*$Id: main.cc,v 21.11 2002/03/17 07:29:01 al Exp $ -*- C++ -*-
+/*$Id: main.cc,v 24.7 2003/05/30 08:08:17 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -58,7 +58,7 @@ int main(int argc, const char *argv[])
       //try {
       char cmdbuf[BUFLEN];
       CMD::count++;
-      getcmd("-->", cmdbuf, BUFLEN);
+      getcmd(I_PROMPT, cmdbuf, BUFLEN);
       CMD::cmdproc(cmdbuf);
     }else{
       //}catch (...){
@@ -70,15 +70,16 @@ int main(int argc, const char *argv[])
 /*--------------------------------------------------------------------------*/
 static void sign_on(void)
 {
-  IO::mstdout << "Gnucap 0." << PATCHLEVEL << '\n'
-	      << "The Gnu Circuit Analysis Package\n"
-	      << "Never trust any version less than 1.0\n"
-	      << "Copyright 1982-2002, Albert Davis\n"
-	      << "Gnucap comes with ABSOLUTELY NO WARRANTY\n"
-	      << "This is free software, and you are welcome\n"
-	      << "to redistribute it under certain conditions\n"
-	      << "according to the GNU General Public License.\n"
-	      << "See the file \"COPYING\" for details\n";
+  IO::mstdout <<
+    "Gnucap "  PATCHLEVEL  "\n"
+    "The Gnu Circuit Analysis Package\n"
+    "Never trust any version less than 1.0\n"
+    "Copyright 1982-2002, Albert Davis\n"
+    "Gnucap comes with ABSOLUTELY NO WARRANTY\n"
+    "This is free software, and you are welcome\n"
+    "to redistribute it under certain conditions\n"
+    "according to the GNU General Public License.\n"
+    "See the file \"COPYING\" for details.\n";
 }
 /*--------------------------------------------------------------------------*/
 static void read_startup_files(void)
