@@ -1,4 +1,4 @@
-/*$Id: s__aux.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: s__aux.cc,v 22.15 2002/08/03 06:54:40 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -48,4 +48,11 @@ void SIM::restore()
   }
 }
 /*--------------------------------------------------------------------------*/
+void SIM::zero_voltages()
+{
+  for (int ii = 1;  ii <= STATUS::total_nodes;  ++ii) {
+    vt1[ii] = v0[ii] = vdc[ii] = i[ii] = 0.;
+  }
+}
+/*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
