@@ -1,4 +1,4 @@
-/* $Id: s__init.cc,v 21.14 2002/03/26 09:20:25 al Exp $
+/* $Id: s__init.cc,v 24.6 2003/05/08 09:04:04 al Exp $
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -31,7 +31,6 @@
 //	 void	SIM::reset_timers();
 //static void	SIM::count_nodes();
 //static void	SIM::alloc_hold_vectors();
-//static void	SIM::determine_matrix_structure(const CARD *stop);
 //	 void	SIM::alloc_vectors();
 //static void	SIM::unalloc_vectors();
 //static void	SIM::uninit();
@@ -62,13 +61,15 @@ void SIM::command_base(CS& cmd)
       /*nothing*/
       break;
     }
-    lu.unallocate();
-    aa.unallocate();
     unalloc_vectors();
     env = stash;
     finish();
   }else{
     //}catch (...) {
+    ++STATUS::iter[iTOTAL];
+    lu.unallocate();
+    aa.unallocate();
+    unalloc_vectors();
     env = stash;
     finish();
     error(bERROR, "");
@@ -90,8 +91,10 @@ void SIM::command_base(CS& cmd)
     aa.reinit(STATUS::total_nodes);
     lu.reinit(STATUS::total_nodes);
     acx.reinit(STATUS::total_nodes);
-    determine_matrix_structure(CARD_LIST::card_list);
-    CARD_LIST::card_list.precalc();  
+    CARD_LIST::card_list.tr_alloc_matrix();
+    CARD_LIST::card_list.ac_alloc_matrix();
+    CARD_LIST::card_list.precalc();
+    last_time = 0;
   }
 }
 /*--------------------------------------------------------------------------*/
@@ -121,13 +124,12 @@ void SIM::reset_timers()
 /*static*/ void SIM::count_nodes()
 {
   STATUS::user_nodes = 0;
-  for (CARD_LIST::const_iterator
-	 ci=CARD_LIST::card_list.begin();ci!=CARD_LIST::card_list.end();++ci) {
-    CARD* brh = *ci;
-    if (brh->is_device()) {
-      for (int ii = 0;  ii < brh->port_count();  ++ii) {
-	if (brh->_n[ii].e > STATUS::user_nodes) {
-	  STATUS::user_nodes = brh->_n[ii].e;
+  for (CARD_LIST::const_iterator ci = CARD_LIST::card_list.begin();
+       ci != CARD_LIST::card_list.end(); ++ci) {
+    if ((**ci).is_device()) {
+      for (int ii = 0;  ii < (**ci).out_nodes();  ++ii) {
+	if ((**ci)._n[ii].e_() > STATUS::user_nodes) {
+	  STATUS::user_nodes = (**ci)._n[ii].e_();
 	}
       }
     }
@@ -157,47 +159,21 @@ void SIM::alloc_hold_vectors()
   std::fill_n(vdc, STATUS::total_nodes+1, 0);
 }
 /*--------------------------------------------------------------------------*/
-/* determine_matrix_structure: 
- * scan the list and tell the matrix which entries to allocate
- * recursive for subckts
- */
-void SIM::determine_matrix_structure(const CARD_LIST& cl)
-{
-  for (CARD_LIST::const_iterator ci = cl.begin();  ci != cl.end();  ++ci) {
-    const CARD* brh = *ci;
-    if (brh->is_device()) {
-      for (int ii = 0;  ii < brh->port_count();  ++ii) {
-	assert(brh->_n[ii].m != INVALID_NODE);
-	if (brh->_n[ii].m != 0) {
-	  for (int jj = 0;  jj < ii ;  ++jj) {
-	    aa.iwant(brh->_n[ii].m,brh->_n[jj].m);
-	    lu.iwant(brh->_n[ii].m,brh->_n[jj].m);
-	    acx.iwant(brh->_n[ii].m,brh->_n[jj].m);
-	  }
-	  nstat[brh->_n[ii].m].set_needs_analog();
-	}
-      }
-      if (brh->subckt().exists()) {
-	determine_matrix_structure(brh->subckt());
-      }
-    }
-  }
-}
-/*--------------------------------------------------------------------------*/
 /* alloc_vectors:
- * allocate space for the right-side vector
- * (initially current sources, on solution becomes voltages) and copies
- * used for one-time-ago and convergence checking
  * these are new with every run and are discarded after the run.
  */
 void SIM::alloc_vectors()
 {
-  unalloc_vectors();	/* usually unnecessary. */
-  assert(!ac);		/* may be needed after exception */
+  assert(evalq1.empty());
+  assert(evalq2.empty());
+  assert(evalq != evalq_uc);
+
+  assert(!ac);
   assert(!i);
   assert(!v0);
   assert(!vt1);
   assert(!fw);
+
   ac = new COMPLEX[STATUS::total_nodes+1];
   i   = new double[STATUS::total_nodes+1];
   v0  = new double[STATUS::total_nodes+1];
@@ -212,6 +188,8 @@ void SIM::alloc_vectors()
 /*--------------------------------------------------------------------------*/
 /*static*/ void SIM::unalloc_vectors()
 {
+  evalq1.clear();
+  evalq2.clear();
   delete [] i;
   i = NULL;
   delete [] v0;
