@@ -1,4 +1,4 @@
-/*$Id: s_fo_out.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: s_fo_out.cc,v 22.5 2002/07/07 07:26:31 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -44,6 +44,7 @@ void FOURIER::store()
   int ii = 0;
   for (PROBELIST::const_iterator
 	 p=printlist().begin();  p!=printlist().end();  ++p){
+    assert(stepno < timesteps);
     fdata[ii][stepno] = p->value();
     ++ii;
   }
@@ -82,7 +83,9 @@ void FOURIER::fohead(const PROBE& prob)
 void FOURIER::foprint(COMPLEX *data)
 {
   int startstep = stepnum(0., fstep, fstart);
+  assert(startstep >= 0);
   int stopstep  = stepnum(0., fstep, fstop );
+  assert(stopstep < timesteps);
   COMPLEX maxvalue = find_max(data,std::max(1,startstep),stopstep);
   if (maxvalue == 0.){
     untested();
@@ -91,6 +94,8 @@ void FOURIER::foprint(COMPLEX *data)
   data[0] /= 2;
   for (int ii = startstep;  ii <= stopstep;  ++ii){
     double frequency = fstep * ii;
+    assert(ii >= 0);
+    assert(ii < timesteps);
     COMPLEX unscaled = data[ii];
     COMPLEX scaled = unscaled / maxvalue;
     unscaled *= 2;
