@@ -1,4 +1,4 @@
-/*$Id: u_opt.h,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: u_opt.h,v 24.11 2003/11/21 03:29:03 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -73,6 +73,17 @@ enum RUN_MODE {
   rBATCH	/* execute now, as a command, then exit		*/
 };
 /*--------------------------------------------------------------------------*/
+/* secant strategy is not implemented but it is a well known
+ * method which may sometime be added
+ */
+#ifdef KNEECHORD
+enum strategy_t {stNEWTON, stKNEECHORD, stSECANT};
+inline OMSTREAM& operator<<(OMSTREAM& o, strategy_t t){
+  const char* s[] = {"newton", "kneechord", "secant"};
+  return (o << s[t]);
+}
+#endif
+/*--------------------------------------------------------------------------*/
 enum {dsINIT=001, dsRANGE=002, dsDEVLIMIT=004, dsDEVREGION=010, dsREVERSE=020};
 /*--------------------------------------------------------------------------*/
 class OPT {
@@ -114,6 +125,8 @@ public:
   static double defas;	    // MOS default source diffusion area
   
   static int seed;	    // random number seed
+  static bool clobber;	    // allow to overwrite files without question
+  static bool named_nodes;  // use alphanumeric node names (false=numbers only)
   static double wczero;	    // worst case zero window
   static double floor;	    // display as zero if less than this
   static double vfloor;	    // display voltages as zero if less than this  
@@ -154,6 +167,8 @@ public:
   static int foooo;	    // a reusable value to aid development
   static int diodeflags;    // convergence heuristic flags for diode
   static int mosflags;	    // convergence heuristic flags for mosfet
+  static bool quitconvfail; // quit on convergence failure
+  static bool edit;	    // use readline - command editing
   
   static double lowlim;	    // 1 - reltol
   static double uplim;	    // 1 + reltol
@@ -166,6 +181,9 @@ public:
 			    // 6=source stepping iteration limit
 			    // 7=worst case iteration limit
 			    // 8=trace nonconvergence start iteration
+#ifdef KNEECHORD
+  static strategy_t strategy; // What method we use to encourage non-linear devices to converge
+#endif
 };
 /*--------------------------------------------------------------------------*/
 class ENV {
