@@ -1,4 +1,4 @@
-/*$Id: u_opt1.cc,v 21.14 2002/03/26 09:20:25 al Exp $ -*- C++ -*-
+/*$Id: u_opt1.cc,v 24.18 2004/01/11 06:57:39 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -54,6 +54,8 @@ double	OPT::defad = 0.;
 double	OPT::defas = 0.;
 
 int	OPT::seed = 1;
+bool	OPT::clobber = true;
+bool	OPT::named_nodes = false;
 double	OPT::wczero = 1e-9;
 double	OPT::floor = 1e-21;
 double	OPT::vfloor = 1e-15;
@@ -65,7 +67,7 @@ double	OPT::tempamb = 27.0-ABS_ZERO;
 double	OPT::shortckt = 10e-6;
 int	OPT::picky = bPICKY;
 int	OPT::inwidth = 80;
-int	OPT::outwidth = 80;
+int	OPT::outwidth = 9999;
 double	OPT::xdivisions = 4.;
 double	OPT::ydivisions = 4.;
 phase_t	OPT::phase = pDEGREES;
@@ -94,6 +96,8 @@ bool	OPT::showall = false;
 int	OPT::foooo = 0;
 int	OPT::diodeflags = 0;
 int	OPT::mosflags = 0;
+bool	OPT::quitconvfail = false;
+bool	OPT::edit = true;
 
 double	OPT::lowlim = 1. - OPT::reltol;
 double	OPT::uplim = 1. + OPT::reltol;
@@ -111,3 +115,6 @@ int	OPT::itl[OPT::ITL_COUNT] = {
 };
 
 RUN_MODE ENV::run_mode = rBATCH;
+#ifdef KNEECHORD
+strategy_t OPT::strategy = stNEWTON; /* Default is Newton's Method, fastest */
+#endif
