@@ -1,4 +1,4 @@
-/*$Id: u_statu2.cc,v 21.8 2002/03/07 08:30:28 al Exp $ -*- C++ -*-
+/*$Id: u_statu2.cc,v 22.10 2002/07/26 03:15:27 al Exp $ -*- C++ -*-
  * Copyright (C) 2001 Albert Davis
  * Author: Albert Davis <aldavis@ieee.org>
  *
@@ -95,7 +95,8 @@ void STATUS::command(CS& cmd)
 	"models:  diodes=%d, bjts=%d, mosfets=%d, gates=%d, subckts=%d\n",
 	MODEL_DIODE::count(), MODEL_BJT::count(), MODEL_MOS_BASE::count(),
 	MODEL_LOGIC::count(), MODEL_SUBCKT::count());
-  IO::mstdout.form("density=%.1f%%\n", aa.density()*100.);
+  IO::mstdout.form("dctran density=%.1f%%, ac density=%.1f%%\n",
+		   aa.density()*100., acx.density()*100.);
 }
 /*--------------------------------------------------------------------------*/
 /*--------------------------------------------------------------------------*/
